// NewsMLExplorer.java - demo application for exploring NewsML packages.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: NewsMLExplorer.java,v 1.6 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


import java.io.File;

import java.net.MalformedURLException;
import java.net.URL;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import org.newsml.toolkit.dom.DOMNewsMLFactory;
import org.newsml.toolkit.dom.XercesDOMFactory;

import org.newsml.toolkit.explorer.ExplorerFrame;


/**
 * Demo application for exploring a NewsML package.
 *
 * <p>Usage:</p>
 *
 * <pre>
 * java NewsMLExplorer [url]
 * </pre>
 *
 * <p>where <code>[url]</code> is an optional argument providing
 * the relative or absolute URL of a NewsML package to load on
 * startup.</p>
 *
 * <p>Most of the work of the application is done by the {@link
 * org.newsml.toolkit.explorer.ExplorerFrame} class.  This application
 * class simply creates and opens the frame, then passes on its
 * command-line argument.  This application uses the Xerces parser and
 * DOM library.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public class NewsMLExplorer
{


    ////////////////////////////////////////////////////////////////////
    // Static methods.
    ////////////////////////////////////////////////////////////////////

    /**
     * Main application entry point.
     *
     * @param args The command-line arguments.  The first argument
     * [if present] will be used as the URL of a NewsML package
     * to open on startup, and any others will be ignored.
     */
    public static void main (String args[])
    {
				// Create the top-level frame.
	ExplorerFrame explorer =
	    new ExplorerFrame(new DOMNewsMLFactory(new XercesDOMFactory()));
	explorer.pack();
	explorer.setVisible(true);

				// Read in any NewsML packages specified
				// on the command line.
	if (args.length > 0)
	    explorer.readNewsML(args[0]);

				// Quit when the window is closed.
	explorer.addWindowListener(new WindowAdapter () {
		public void windowClosing (WindowEvent e) {
		    System.exit(0); // FIXME
		}
	    });
    }
}


// end of NewsMLExplorer.java
