// AssignmentNode.java - interface for nodes with assignment information.
// Copyright (c) 2001 by Reuters PLC and Wavo Company, Inc.
// $Id: AssignmentNode.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Interface for nodes with assignment information.
 *
 * <p>This is a common base interface for other interfaces, capturing
 * common sets of access methods for assignment and responsibility
 * information.  It parallels the %assignment; parameter entity in the
 * NewsML XML DTD.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface AssignmentNode
{

    /**
     * Get the party assigning the information.
     *
     * <p>The return value of this method may be general prose text
     * (intended for human consumption) <em>or</em> a fragment
     * identifier, beginning with '#', intended to allow a computer to
     * look up a Topic by Duid.  Obviously, there is room for
     * confusion; for example, if an editor were identified by a
     * number, as in "#S45674", a system might misinterpret that as a
     * fragment identifier and try to look up the corresponding Topic.
     * <strong>BEWARE!</strong>.</p>
     *
     * <p>If a client application is fairly certain that the text does
     * contain a fragment identifier and wants to locate the
     * corresponding Topic, it can use the {@link
     * NewsMLSession#getNodeByDuid} in the {@link NewsMLSession}
     * interface (available through {@link BaseNode#getSession}).</p>
     *
     * @return A text node containing freeform text or a fragment
     * identifier (starting with '#') pointing to a topic.
     */
    public Text getAssignedBy ();


    /**
     * Get the importance assigned to the information.
     *
     * <p>The formal name returned will never have a local scheme
     * or vocabulary, but it may have a default one.</p>
     *
     * @return Text representing the local part of a formal name.
     */
    public FormalName getImportance ();


    /**
     * Get the confidence assigned to the information.
     *
     * <p>The formal name returned will never have a local scheme
     * or vocabulary, but it may have a default one.</p>
     *
     * @return Text representing the local part of a formal name.
     */
    public FormalName getConfidence ();


    /**
     * Get the applicability of the information.
     *
     * <p>The formal name returned will never have a local scheme
     * or vocabulary, but it may have a default one.</p>
     *
     * @return Text representing the local part of a formal name.
     */
    public FormalName getHowPresent ();


    /**
     * Get the date and time of assignment.
     *
     * <p>Renamed to avoid confusion with date and time element, where
     * present.</p>
     *
     * @return Text containing the date in ISO 8601 basic format.
     */
    public Text getAssignmentDateAndTime ();

}

// end of AssignmentNode.java
