// BasisForChoice.java - basis for choosing among equivalents.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: BasisForChoice.java,v 1.10 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Basis for choosing among equivalent news components or content items.
 *
 * <p>When a {@link NewsComponent} is an equivalents list (see {@link
 * NewsComponent#getEquivalentsList}) it may provide one or more hints
 * on how to select from the list.  This interface provides an XPath
 * to the relevant information (requiring, unfortunately, access to
 * the full DOM tree) together with ranking information.</p>
 *
 * <p>Note that the documentation does not specifically state that
 * basis for choice can apply to an equivalents list of {@link
 * NewsItem} or {@link NewsItemRef} members in a news component; use
 * with caution until the IPTC clarifies the rules.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface BasisForChoice
    extends IdText
{

    /**
     * Rank this basis for choice.
     *
     * <p>To get the rank as an integer, use the return value's {@link
     * Text#toInt} method.</p>
     *
     * @return Text containing an integer ranking this basis for
     * choice among the others (a lower number indicates higher
     * importance), or null if no explicit rank was provided.
     */
    public Text getRank ();

}

// end of BasisForChoice.java
