// Characteristics.java - physical characteristics of a content item.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: Characteristics.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Physical characteristics of a content item.
 *
 * <p>This interface provides information about physical size of a
 * content item in bytes, and may also provide other information
 * through the generic {@link Property} interface.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface Characteristics
    extends BaseNode, IdNode, PropertyNode
{

    /**
     * Get the size of the actual content in bytes.
     *
     * <p>To get the size as an integer, use the {@link Text#toInt}
     * method on the return value.</p>
     *
     * @return Text containing the size of the content in bytes or
     * null if the size was not specified.
     */
    public IdText getSizeInBytes ();

}


// end of Characteristics.java
