// Comment.java - a comment (element) in a NewsML document
// Copyright (c) 2001 by Reuters PLC.
// $Id: Comment.java,v 1.9 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;

import java.io.IOException;


/**
 * A comment node in a NewsML document.
 *
 * <p>Many different element types in a NewsML document can have prose
 * comments attached, possibly in multiple languages.  These are not
 * to be confused with XML comments (&lt;!-- ... --&gt;), which are
 * discarded during import.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface Comment
    extends IdText, LanguageNode
{

    /**
     * Get the identifier of another comment translated by this one.
     *
     * @return Text containing the Duid of the original version of
     * this comment.
     * @see #getReferencedComment
     */
    public Text getTranslationOf ();


    /**
     * Get the comment referenced by TranslationOf.
     *
     * @return The referenced comment, or null if not found.
     * @exception NewsMLException if the referenced node is not a comment.
     * @see #getTranslationOf
     */
    public Comment getReferencedComment ()
	throws IOException;

}


// end of Comment.java
