// CommentNode.java - interface for nodes with comments.
// Copyright (c) 2001 by Reuters PLC and Wavo Company, Inc.
// $Id: CommentNode.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Interface for nodes with comments.
 *
 * <p>All node types that can have comments attached implement this
 * interface.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface CommentNode
{

    /**
     * Count the comments attached to this node.
     *
     * @return The number of comments.
     */
    public int getCommentCount ();
    

    /**
     * Get one of the comments attached to this node.
     *
     * @param index The index of the comment.
     * @return The comment, or null if none was provided at the
     * specified index.
     */
    public Comment getComment (int i);


    /**
     * Get all Comment children in an array.
     *
     * @return A (possibly-empty) array of Comment children.
     */
    public Comment [] getComment ();

}

// end of CommentNode.java
