// DataContent.java - basis for choosing among equivalents.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: DataContent.java,v 1.5 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;

import org.w3c.dom.NodeList;


/**
 * Raw inline data in leaf content.
 *
 * <p>Currently, this interface returns the raw inline data as a DOM
 * node list.  That will be awkward for some implementations, especially
 * for any future implementations not based on a DOM tree.  Possible
 * future alternatives include returning all of the inline data as a
 * string, and providing mechanisms for decoding encoded inline data
 * (i.e. base64 and similar) to produce binary objects.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface DataContent
    extends BaseNode, IdNode
{

    /**
     * Get the inline data as a list of DOM nodes.
     *
     * <p>This method may return more than one top-level node,
     * possibly accompanied by text and whitespace.</p>
     *
     * @return The list of DOM nodes inside the DataContent element.
     */
    public NodeList getDOMNodes ();


    /**
     * Get the inline data as plain text, ignoring any XML markup.
     *
     * <p>This method is most useful when the inline content is
     * base64-encoded binary data or something similar, where XML
     * markup is not relevant and XML character escaping is
     * undesirable.</p>
     *
     * @return A string of raw text, with no XML character escaping.
     */
    public String getText ();


    /**
     * Get the inline data as a fragment of XML markup.
     *
     * <p>This method is most useful when the inline content is
     * NITF or XHTML XML markup or something similar, where the
     * markup needs to be preserved for parsing by another software
     * component.  Note that the string is *not* guaranteed to be
     * a well-formed XML document, since it may contain more than
     * one top-level element.</p>
     *
     * @return A string containing a logically-equivalent (*not*
     * identical) XML document that can be passed to a parser for
     * further processing.
     * @see BaseNode#toXML
     * @see BaseNode#writeXML
     */
    public String getXMLString ();
    
}

// end of DataContent.java
