// DefaultVocabularyFor.java - text with identifiers and origin subelements.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DefaultVocabularyFor.java,v 1.9 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * A default vocabulary declaration.
 *
 * <p>This class represents a default vocabulary for all formal
 * names that occur in markup matching the XPath expression provided
 * by the {@link #getContext} method.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface DefaultVocabularyFor
    extends BaseNode, IdNode
{

    /**
     * Get the XPath expression to match.
     *
     * <p>It is assumed in the {@link FormalNameNode} class (in the
     * {@link FormalNameNode#getDefaultVocabulary} and {@link
     * FormalNameNode#getDefaultScheme} methods) that the context node
     * for the XPath expression is the parent of the Catalog
     * containing this declaration.  The NewsML 1.0 functional
     * specification does not state what the context node should
     * be.</p>
     *
     * @return Text containing a relative XPath expression (not null).
     */
    public Text getContext ();


    /**
     * Get the scheme to be applied to any matches.
     *
     * @return Text containing the scheme string, or null if none was
     * provided.
     */
    public Text getScheme ();

}

// end of DefaultVocabularyFor.java
