// Encoding.java - basis for choosing among equivalents.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: Encoding.java,v 1.6 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;

import org.w3c.dom.NodeList;


/**
 * An encoding step for raw inline content.
 *
 * <p>This class defines an encoding step performed on the raw, inline
 * content.  Exactly one of {@link #getEncoding} or {@link #getDataContent}
 * will return a non-null value, as with {@link ContentItem}.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface Encoding
    extends BaseNode, IdNode
{

    /**
     * Get the notation for the data content.
     *
     * <p>It is possible that this attribute value was intended to be
     * treated as a formal name, but there is no explicit statement in
     * the NewsML 1.0 Functional Specification or the DTD that says
     * so.</p>
     *
     * @return Text describing the notation for this encoding step.
     */
    public Text getNotation ();


    /**
     * Get a further encoding step.
     *
     * @return A futher encoding step, or null if none was provided
     *         (in which case {@link #getDataContent} will return
     *         a non-null value).
     */
    public Encoding getEncoding ();


    /**
     * Get the raw inline content.
     *
     * @return An object containing the raw content, or null if a
     *         further encoding step is present (in which case {@link
     *         #getEncoding} will return a non-null value).
     */
    public DataContent getDataContent ();

}

// end of Encoding.java
