// EquivalentNode.java - an member within a NewsComponent
// Copyright (c) 2001 by Reuters PLC.
// $Id: EquivalentNode.java,v 1.3 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * An member within a NewsComponent.
 *
 * <p>A news component may contain one or more NewsItems and
 * NewsItemRefs, NewsComponents, or ContentItems.  These members may
 * or may not be equivalents (see {NewsComponent#getEquivalentsList});
 * if they are equivalents, the NewsML document may have provided a
 * basis for choosing among them.  This interface provides a method
 * that allows a client application quickly to find the node that is
 * the basis for choice among the descendants of each member.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface EquivalentNode
    extends BaseNode
{


    /**
     * Get the nodes that are the basis for choosing among the members.
     *
     * <p>This method returns an array with one entry for each
     * BasisForChoice element in the parent NewsComponent.  If there
     * is no match for the XPath expression in one of the
     * BasisForChoice elements, the corresponding entry will be null.
     * The nodes will be sorted as in {@link
     * NewsComponent#getRankedBasisForChoice}.</p>
     *
     * @return An array of nodes (possibly empty), in ranked
     * order from most to least important basis for choice.  Some
     * entries may be null.
     * @exception NewsMLException If there is an error in the XPath
     * expression in the XML source document.
     */
    public BaseNode [] getBasisForChoiceNodes ()
	throws NewsMLException;

}

// end of EquivalentNode.java
