// FormalName.java - a three-part NewsML formal name element.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: FormalName.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;

import java.io.IOException;


/**
 * A three-part NewsML name element.
 *
 * <p>For information on formal names, see the {@link FormalNameNode}
 * base interface.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface FormalName
    extends BaseNode, FormalNameNode, IdNode
{

    /**
     * Get an explicitly-specified scheme for the formal name.
     *
     * <p>This method returns only a scheme that has been provided
     * explicitly in the XML.</p>
     * 
     * <p>A scheme is a section of a vocabulary; this property is
     * useful for partitioning large vocabularies into several
     * parts.</p>
     *
     * <p>This method is not declared present in the {@link
     * FormalNameNode} base interface because an explicitly-specified
     * scheme is not available for the {@link ProviderId}
     * interface.</p>
     *
     * @return Text containing the vocabulary scheme, or null if none
     * was provided.
     * @see #getDefaultScheme
     * @see #getName
     * @see #getVocabulary
     */
    public Text getScheme ();

}

// end of FormalName.java
