// FormalNameDecl.java - a three-part NewsML formal name.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: FormalNameDecl.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;

import java.io.IOException;


/**
 * The declaration of a local name and scheme for a topic.
 *
 * <p>When a {@link TopicSet} represents a vocabulary, this element
 * can declare a local name (the value of this text node) and optional
 * scheme for a topic.  Note that in the NewsML XML markup, the
 * element is named simply "FormalName".  The combination of local
 * name and scheme will be unique among all topics in the topic
 * set.</p>
 *
 * <p>Note that a single topic may have zero or more formal names
 * declared.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see FormalName
 */
public interface FormalNameDecl
    extends IdText
{

    /**
     * Get a topic's declared scheme.
     *
     * @return Text containing the vocabulary scheme, or null if none
     * was provided.
     * @see FormalName#getScheme()
     */
    public Text getScheme ();

}

// end of FormalNameDecl.java
