// HeadLineGroup.java - a user-defined news line
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: HeadLineGroup.java,v 1.6 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * A headline/subheadline pair.
 *
 * <p>This interface represents an implicit grouping that is not
 * actually represented by an XML element: as a result, it does not 
 * extend the BaseNode interface.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface HeadLineGroup
{

    /**
     * Get the headline from the group.
     *
     * @return A headline as mixed-content text with origin
     * information (not null).
     * @see #getSubHeadLine
     */
    public OriginText getHeadLine ();


    /**
     * Get the subheadline from the group.
     *
     * @return A subheadline as mixed-content text with origin
     * information, or null if no subheadline was provided.
     * @see #getHeadLine
     */
    public OriginText getSubHeadLine ();

}

// end of HeadLineGroup.java
