// IdNode.java - base node for an identifiable NewsML object.
// Copyright (c) 2001 by Reuters PLC
// $Id: IdNode.java,v 1.9 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Base node for identifiable NewsML objects.
 *
 * <p>Most NewsML objects can have a Duid (document-unique
 * identifiers) and/or Euid (element-unique identifier) attached.  All
 * such objects are derived from this class.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface IdNode
{

    /**
     * Get the Duid for this element.
     *
     * The Duid, or Document-Unique Identifier, is a string identifier
     * guaranteed to be unique within this NewsML package.  Duids are
     * heavily used for cross-referencing.
     *
     * @return Text containing the document-unique identifier for the
     * underlying XML element, or null if none was specified.
     */
    public Text getDuid ();


    /**
     * Get the Euid for this element.
     *
     * The Euid, or Element-Unique Identifier is not likely to be used
     * widely -- it's an identifier that unique only among elements
     * with the same type and parent (and thus, is virtually useless
     * for cross-referencing).  This toolkit includes access to the
     * Euid simply for the sake of completeness, but all of its
     * retrieval and cross-referencing support is based on the Duid.
     *
     * Note that this method will always return null for instances of
     * the {@link NewsIdentifier}, {@link RevisionId}, and {@link
     * TopicUse} classes.
     *
     * @return Text containing the element-unique identifier for the
     * underlying XML element, or null if none was specified.
     */
    public Text getEuid ();

}

// end of IdNode.java
