// Identification.java - identification labels for a NewsItem.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: Identification.java,v 1.7 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Identification labels for a NewsItem
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface Identification
    extends BaseNode, IdNode
{

    /**
     * Get the identification information for this news item.
     *
     * The identification information allows you to determine
     * which news items are new and which are updated versions
     * of previous ones.
     *
     * @return An object containing the identification information
     * (not null).
     */
    public NewsIdentifier getNewsIdentifier ();


    /**
     * Get the optional name label.
     *
     * @return A text object representing the name label, or null
     * if none was provided.
     */
    public IdText getNameLabel ();


    /**
     * Get the optional date label.
     *
     * @return A text object representing the date label, or null
     * if none was provided.
     */
    public IdText getDateLabel ();


    /**
     * Count the generic labels.
     *
     * @return The number of generic labels present.
     */
    public int getLabelCount ();

 
   /**
     * Get a generic label.
     *
     * @param index The position of the label, zero-based, numbered
     * sequentially.
     * @return A text object representing the name label, or null
     * if none was provided at the index specified.
     */
    public Label getLabel (int index);


    /**
     * Get an array of all available labels.
     *
     * @return A (possibly empty) array of labels.
     */
    public Label [] getLabel ();

}

// end of Identification.java
