// Instruction.java - an instruction from a news provider.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: Instruction.java,v 1.6 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * An instruction from a news provider.
 *
 * <p>Instructions are available through the {@link NewsManagement}
 * information for a {@link NewsItem}.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface Instruction
    extends FormalName
{

    /**
     * Count the revision status structures present.
     *
     * @return The number of revision status structures.
     */
    public int getRevisionStatusCount ();


    /**
     * Get the effect of this revision on previous revisions.
     *
     * @param index The index of the revision status object, zero-based,
     * numbered sequentially.
     * @return The RevisionStatus object, or null if none was provided
     * at the specified index.
     */
    public RevisionStatus getRevisionStatus (int index);


    /**
     * Get all RevisionStatus children in an array.
     *
     * @return A (possibly-empty) array of RevisionStatus children.
     */
    public RevisionStatus [] getRevisionStatus ();

}

// end of Instruction.java
