// LanguageNode.java - interface for nodes with properties.
// Copyright (c) 2001 by Reuters PLC and Wavo Company, Inc.
// $Id: LanguageNode.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Interface for nodes with a natural language code attached.
 *
 * <p>This interface applies specifically to elements that use the
 * xml:lang attribute to provide a natural-language code, usually
 * using ISO 639 codes such as "fr" for French or "en-UK" for British
 * English.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface LanguageNode
{

    /**
     * Get the language code.
     *
     * @return Text containing the language code, as provided by the
     * xml:lang attribute in the XML source, or null if none was
     * provided.
     */
    public Text getLang ();

}

// end of LanguageNode.java
