// NewsItemId.java - a news item identifier.
// Copyright (c) 2001 by Reuters PLC.
// $Id: NewsItemId.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;

import java.io.IOException;


/**
 * A news item identifier.
 *
 * <p>A news item identifier is similar to a regular {@link FormalName},
 * but it does not contain the local Duid or Euid identifiers.  It is
 * also similar to a {@link ProviderId}, except that it can have a
 * locally-specified scheme.  See {@link FormalName} for details on
 * vocabulary resolution.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface NewsItemId
    extends BaseNode, FormalNameNode
{

    /**
     * Get an explicitly-specified scheme for the formal name.
     *
     * <p>This method returns only a scheme that has been provided
     * explicitly in the XML.</p>
     * 
     * <p>A scheme is a section of a vocabulary; this property is
     * useful for partitioning large vocabularies into several
     * parts.</p>
     *
     * @return Text containing the vocabulary scheme, or null if none
     * was provided.
     */
    public Text getScheme ();

}

// end of NewsItemId.java
