// NewsLine.java - a user-defined news line
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: NewsLine.java,v 1.6 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * A user-defined news line.
 *
 * <p>NewsML provides several explicit types of news lines, including
 * the headline, subheadline, byline, dateline, and several others.
 * This interface represents any news lines not belonging to those
 * types.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface NewsLine
    extends BaseNode, IdNode
{

    /**
     * The type of the extended newsline.
     *
     * @return A formal name representing the type (not null).
     */
    public FormalName getNewsLineType ();


    /**
     * Count the text chunks.
     *
     * @return The number of text chunks present.
     */
    public int getNewsLineTextCount ();


    /**
     * A chunk of text for the newsline.
     *
     * @return A chunk of text for the news line.
     */
    public OriginText getNewsLineText (int index);


    /**
     * Get all NewsLineText children in an array.
     *
     * @return A (possibly-empty) array of NewsLineText children.
     */
    public OriginText [] getNewsLineText ();

}

// end of NewsLine.java
