// PartyList.java - a list of parties involved with the NewsML package.
// Copyright (c) 2001 by Reuters PLC.
// $Id: PartyList.java,v 1.6 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * A list of parties connected with the NewsML package.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface PartyList
    extends BaseNode, CommentNode, IdNode
{

    /**
     * Count the parties.
     *
     * @return The number of parties present.
     */
    public int getPartyCount ();


    /**
     * Get one of the parties.
     *
     * @param index The position of the party, zero-based, numbered
     * sequentially in document order.
     * @return The party, or null if none was provided at the
     * specified location.
     */
    public Party getParty (int index);


    /**
     * Get an array of all party objects.
     *
     * @return An array of Party objects, possibly empty.
     */
    public Party [] getParty ();

}

// end of PartyList.java
