// Property.java - a named metadata property.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: Property.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * A named metadata property.
 *
 * <p>NewsML news providers use this property to encode additional
 * information for which there is not explicit NewsML markup.  The
 * Property class is recursive: a property can itself have
 * properties.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface Property
    extends AssignmentNode, BaseNode, FormalNameNode, IdNode, PropertyNode
{

    /**
     * Get a literal string value for the property.
     *
     * If a valueref (see {@link #getValueRef}) is also provided,
     * then the valueref takes precedence and this represents
     * a string rendition of it.
     *
     * @return Text containing a value for the property or null if
     * none was provided.
     * @see #getValueRef
     */
    public Text getValue ();


    /**
     * Get a pointer to a property's value.
     *
     * The data can point to any arbitrary data inside or outside the
     * document, using an internal reference or a URL or URN.  While
     * the target may be a TopicSet, in many circumstances it will
     * be difficult to tell.  Programmers should use this method
     * with caution.
     *
     * @return Text containing an identifier for an external value of
     * some kind (possibly part of this or another XML document).
     * @see #getValue
     */
    public Text getValueRef ();


    /**
     * Get the allowed values for the property.
     *
     * A pointer to a controlled vocabulary enumerating the allowed values
     * for this property.  The pointer may be an internal fragment
     * identifier (starting with '#'), a URL, or a URN, presumably
     * leading to a TopicSet.  Programmers should use this method
     * with caution, especially given the difficulty of resolving
     * URNs.
     *
     * @return Text containing the identifier of the vocabulary.
     * @see #getValue
     * @see #getValueRef
     */
    public Text getAllowedValues ();

}

// end of Property.java
