// Resource.java - information about a single metadata resource.
// Copyright (c) 2001 by Reuters PLC.
// $Id: Resource.java,v 1.7 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Information about a single resource.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface Resource
    extends BaseNode, IdNode
{

    /**
     * Get the URN attached to the resource, if any.
     *
     * <p>A resource may have only a single URN.</p>
     *
     * @return The URN as text, or null if none was provided.
     */
    public IdText getUrn ();


    /**
     * Count the URLs
     *
     * @return The number of URLs present.
     */
    public int getUrlCount ();


    /**
     * Get a URL attached to the resource.
     *
     * @param index The index of the resource, zero-based, numbered
     * sequentially in document order.
     * @return The URL as text, or null if none was present
     * at the index provided.
     */
    public IdText getUrl (int index);


    /**
     * Get all Url children in an array.
     *
     * @return A (possibly-empty) array of Url children.
     */
    public IdText [] getUrl ();


    /**
     * Count the default vocabulary declarations.
     *
     * @return The number of default vocabulary declarations present.
     */
    public int getDefaultVocabularyForCount ();


    /**
     * Get a default vocabulary declaration for this resource.
     *
     * @param index The index of the declaration, zero-based, numbered
     * sequentially in document order.
     * @return An object representing a default vocabulary declaration,
     * or null if none was available at the index specified.
     */
    public DefaultVocabularyFor getDefaultVocabularyFor (int index);


    /**
     * Get all DefaultVocabularyFor children in an array.
     *
     * @return A (possibly-empty) array of DefaultVocabularyFor children.
     */
    public DefaultVocabularyFor [] getDefaultVocabularyFor ();

}

// end of Resource.java
