// RevisionStatus.java - a new status for a previous revision.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: RevisionStatus.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * A new status for a previous revision.
 *
 * <p>The RevisionStatus provides a new status for a previous revision
 * as a result of the release of the current revision: in plain
 * English, now the new version of the news item is out, the status of
 * the old one is as follows...</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface RevisionStatus
    extends BaseNode, IdNode
{

    /**
     * Get the new status for the past revision.
     *
     * @return A formal name representing the new status (not null).
     * @see #getRevision
     */
    public FormalName getStatus ();


    /**
     * Get the revision to which the new status applies.
     *
     * <p>To get the integer value, use the {@link Text#toInt} method
     * in the {@link Text} object returned.</p>
     *
     * @return Text containing positive integer indicating the
     * previous revision, or -1 to indicate <em>all</em> previous
     * revisions.
     */
    public Text getRevision ();

}

// end of RevisionStatus.java
