// RightsMetadata.java - indication about the rights for a news component.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: RightsMetadata.java,v 1.6 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Information about the rights for a news component.
 *
 * <p>Rights typically include time and geographical restrictions and
 * the right to use news content in different ways.  The rights
 * metadata is attached to a {@link NewsComponent}.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface RightsMetadata
    extends AssignmentNode, BaseNode, CatalogNode, IdNode, PropertyNode
{

    /**
     * Count the copyrights.
     *
     * @return The number of copyrights present.
     */
    public int getCopyrightCount ();


    /**
     * Get a copyright attached to the news component.
     *
     * @param index The index of the copyright, zero-based, numbered
     * sequentially.
     * @return An object representing the copyright, or null if none
     * was provided at the specified index.
     */
    public Copyright getCopyright (int index);


    /**
     * Get all Copyright children in an array.
     *
     * @return A (possibly-empty) array of Copyright children.
     */
    public Copyright [] getCopyright ();


    /**
     * Count the usage rights statements.
     *
     * @return The number of usage-rights statements present.
     */
    public int getUsageRightsCount ();


    /**
     * Return the usage rights attached to the news component.
     *
     * @param index The index of the usage rights, zero-based,
     * numbered sequentially.
     * @return An object representing the usage rights, or null if
     * none was provided at the specified index.
     */
    public UsageRights getUsageRights (int index);


    /**
     * Get all UsageRights children in an array.
     *
     * @return A (possibly-empty) array of UsageRights children.
     */
    public UsageRights [] getUsageRights ();

}

// end of RightsMetadata.java
