// StatusWillChange.java - a future status change for a news item.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: StatusWillChange.java,v 1.7 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * A future status change for a news item.
 *
 * <p>This information is part of the {@link NewsManagement}
 * information for a {@link NewsItem}.  It indicates future scheduled
 * status changes, such as a change from embargoed to usable.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface StatusWillChange
    extends BaseNode, IdNode
{

    /**
     * Get the future status.
     *
     * A typical status is embargoed or usable.
     *
     * @return A formal name representing the future status.
     */
    public FormalName getFutureStatus ();


    /**
     * Get the date and time when the future status will take effect.
     *
     * @return Text representing the date and time in ISO 8601
     * basic format.
     */
    public IdText getDateAndTime ();

}

// end of StatusWillChange.java
