// TopicNode.java - an object containing a reference to a Topic.
// Copyright (c) 2001 by Reuters PLC.
// $Id: TopicNode.java,v 1.4 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;

import java.io.IOException;


/**
 * Interface for objects pointing to topics.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface TopicNode
{
    
    /**
     * Get the reference.
     *
     * @return Text containing a pointer to a topic.
     */
    public Text getTopicRef ();


    /**
     * Look up the referenced topic.
     *
     * @param useExternal Look outside the current document for
     * absolute references.  This parameter should be 'true' only
     * for {@link Party}, since {@link TopicOccurrence} and
     * {@link TopicUse} allow only internal topic references.
     * @return The referenced topic, or null if not found.
     * @exception IOException if there is an error looking up the topic
     * in an external document.
     * @exception NewsMLException if the referenced node is not a Topic.
     * @see #getTopicRef
     */
    public Topic getReferencedTopic (boolean useExternal)
	throws IOException;

}

// end of TopicNode.java
