// Update.java - deltas for incremental updates.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: Update.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Deltas for incremental updates.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface Update
    extends IdNode
{

    /**
     * Count the deltas in this update.
     *
     * @return The number of deltas present.
     * @see #getDelta(int)
     */
    public int getDeltaCount ();


    /**
     * Get one of the deltas for the update.
     *
     * <p>The deltas include InsertBefore, InsertAfter, Replace, and
     * Delete.</p>
     *
     * @param index The index of the delta to retrieve, zero-based, numbered
     * sequentially.
     * @return The delta requested, or null if the index is out of range.
     * @see #getDeltaCount()
     * @see #getDelta()
     */
    public Delta getDelta (int index);


    /**
     * Get all of the deltas for the update.
     *
     * @return An array containing all of the delta nodes.
     * @see #getDelta(int)
     */
    public Delta [] getDelta ();

}

// end of Update.java
