// UsageRights.java - usage rights for a news component.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: UsageRights.java,v 1.6 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit;


/**
 * Usage rights for a news component.
 *
 * <p>Usage rights are part of the {@link RightsMetadata} for a {@link
 * NewsComponent}.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface UsageRights
    extends AssignmentNode, BaseNode, IdNode
{

    /**
     * The type of usage to which these rights apply.
     *
     * @return A natural-language description of the usage type (for
     * human presentation).
     */
    public AssignedOriginText getUsageType ();


    /**
     * The geographic area or areas to which these rights apply.
     *
     * @return A natural-language description of the area(s) (for
     * human presentation).
     */
    public AssignedOriginText getGeography ();


    /**
     * The holder or holders of these rights.
     *
     * @return A natural-language description of the rights holder (for
     * human presentation).
     */
    public AssignedOriginText getRightsHolder ();


    /**
     * The terms and conditions of these rights.
     *
     * @return A natural-language description of the limitations (for
     * human presentation).
     */
    public AssignedOriginText getLimitations ();


    /**
     * The date when these rights come into effect.
     *
     * @return A natural-language description of the date (for
     * human presentation).
     */
    public AssignedOriginText getStartDate ();


    /**
     * The date when these rights cease effect.
     *
     * @return A natural-language description of the date (for
     * human presentation).
     */
    public AssignedOriginText getEndDate ();

}

// end of UsageRights.java
