// CatalogTest.java - test a Catalog.
// Copyright (c) 2001 by Reuters PLC.
// $Id: CatalogTest.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import java.io.IOException;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.Catalog;
import org.newsml.toolkit.NewsMLException;
import org.newsml.toolkit.Text;


/**
 * Catalog-specific conformance tests.
 *
 * <p>This class reports an error if a Catalog with an Href attribute
 * has any resources.  The Href itself can be tested with {@link
 * RefTest}.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see NewsMLTestManager
 */
public class CatalogTest
    extends TestBase
{


    /**
     * Run tests for a Catalog node.
     *
     * @param node A Catalog node.
     * @param useExternal Not used.
     * @exception NewsMLException If the test fails.
     * @exception java.lang.ClassCastException If the node parameter is not
     *   an instance of {@link Catalog}. 
     * @see TestBase#run
     */
    public void run (BaseNode node, boolean useExternal)
	throws NewsMLException
    {
	Catalog catalog = (Catalog)node;

	if (catalog.getHref() != null && catalog.getResourceCount() != 0)
	    error("Catalog has Href but also Resource children");
    }

}

// end of CatalogTest.java
