// ConformanceWarning.java - an exception for a non-fatal warning.
// Copyright (c) 2001 by Reuters PLC.
// $Id: ConformanceWarning.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import org.newsml.toolkit.NewsMLException;


/**
 * Exception for a non-fatal warning.
 *
 * <p>This class adds no new methods or functionality to
 * NewsMLException, but it allows a warning to be distinguished from
 * an error in a try...catch construction.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public class ConformanceWarning
    extends NewsMLException
{

    /**
     * Construct a new conformance warning.
     */
    public ConformanceWarning ()
    {
	super();
    }


    /**
     * Construct a new conformance warning with an explicit message.
     *
     * @param message The warning message.
     */
    public ConformanceWarning (String message)
    {
	super(message);
    }


    /**
     * Construct a new conformance warning wrapping another exception.
     *
     * @param exception The exception to wrap.
     */
    public ConformanceWarning (Exception exception)
    {
	super(exception);
    }


    /**
     * Construct a conformance warning with a message and wrapped exception.
     *
     * @param message The warning message.
     * @param exception The exception to wrap.
     */
    public ConformanceWarning (String message, Exception exception)
    {
	super(message, exception);
    }

}

// end of ConformanceWarning.java
