// ContentItemTest.java - test a ContentItem.
// Copyright (c) 2001 by Reuters PLC.
// $Id: ContentItemTest.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import java.io.IOException;
import java.net.URL;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.ContentItem;
import org.newsml.toolkit.NewsMLException;
import org.newsml.toolkit.Text;


/**
 * ContentItem-specific conformance tests.
 *
 * <p>This class reports an error if a ContentItem has both an Href
 * and Encoding or DataContent (DTD conformance can confirm that
 * Encoding and DataContent themselves are mutually-exclusive).</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see NewsMLTestManager
 */
public class ContentItemTest
    extends TestBase
{

    /**
     * Run tests for a ContentItem node.
     *
     * @param node A ContentItem node.
     * @param useExternal Not used.
     * @exception NewsMLException If the test fails.
     * @exception java.lang.ClassCastException If the node parameter is not
     *   an instance of {@link ContentItem}. 
     * @see TestBase#run
     */
    public void run (BaseNode node, boolean useExternal)
	throws NewsMLException
    {
	ContentItem item = (ContentItem)node;

	if (item.getHref() == null) {
	    if (item.getEncoding() == null && item.getDataContent() == null)
		error("ContentItem has no Href, Encoding, or DataContent");
	} else {
	    if (item.getEncoding() != null)
		error("ContentItem has both Href and Encoding");
	    else if (item.getDataContent() != null)
		error("ContentItem has both Href and DataContent");
	}
    }

}

// end of ContentItemTest.java
