// DefaultVocabularyForTest.java - test a DefaultVocabularyFor.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DefaultVocabularyForTest.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.Catalog;
import org.newsml.toolkit.FormalName;
import org.newsml.toolkit.DefaultVocabularyFor;
import org.newsml.toolkit.NewsMLException;


/**
 * DefaultVocabularyFor-specific conformance tests.
 *
 * <p>Test that the declaration matches at least one node somewhere
 * in the subtree, and test that the node it matches is, in fact,
 * a formal name.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see NewsMLTestManager
 */
public class DefaultVocabularyForTest
    extends TestBase
{

    /**
     * Run tests for a DefaultVocabularyFor node.
     *
     * @param node A DefaultVocabularyFor node.
     * @param useExternal Not used.
     * @exception NewsMLException If the test fails.
     * @exception java.lang.ClassCastException If the node parameter is not
     *   an instance of {@link DefaultVocabularyFor}. 
     * @see TestBase#run
     */
    public void run (BaseNode node, boolean useExternal)
	throws NewsMLException
    {
	DefaultVocabularyFor decl = (DefaultVocabularyFor)node;

	String xpath = decl.getContext().toString();
	Catalog catalog = (Catalog)decl.getParent().getParent();
	BaseNode context = catalog.getParent();
	int nMatches = 0;
	BaseNode hits[] = decl.getSession().getNodesByXPath(context, xpath);
	for (int i = 0; i < hits.length; i++) {
	    if (hits[i] != null && isDescendantOf(context, hits[i])) {
		if (!(hits[i] instanceof FormalName) &&
		    !(hits[i].getXMLName().equals("FormalName")))
		    warning("XPath " + xpath + " matches element "
			    + hits[i].getXMLName()
			    + " which is not a formal name");
		nMatches++;
	    }
	}
	if (nMatches < 1)
	    warning("No nodes match XPath: " + xpath);
    }


    private boolean isDescendantOf(BaseNode ancestor, BaseNode descendant)
    {
	BaseNode parent = descendant.getParent();
	while (parent != null) {
	    if (parent.equals(ancestor))
		return true;
	    parent = parent.getParent();
	}
	return false;
    }
    
}

// end of DefaultVocabularyForTest.java

