// EuidTest.java - test the value of Euid attributes.
// Copyright (c) 2001 by Reuters PLC.
// $Id: EuidTest.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.NewsMLException;


/**
 * Euid-specific conformance tests.
 *
 * <p>This class reports an error if a Euid is repeated within nodes
 * of the same type sharing a common parent.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see NewsMLTestManager
 */
public class EuidTest
    extends TestBase
{

    /**
     * Run tests for a Euid node.
     *
     * @param node A Text node containing a Euid.
     * @param useExternal Not used.
     * @exception NewsMLException If the test fails.
     * @see TestBase#run
     */
    public void run (BaseNode node, boolean useExternal)
	throws NewsMLException
    {
	BaseNode parent = node.getParent();
	if (parent == null)
	    return;

	BaseNode grandparent = parent.getParent();
	if (grandparent == null)
	    return;

	String element_name = parent.getXMLName();
	String euid = node.toString();

	if (euid.length() < 1)
	    warning("Empty string for Euid");

	BaseNode matches[] = node.getSession()
	    .getNodesByXPath(grandparent,
			     "./" + element_name + '[' +
			     "@Euid='" + euid + "']");

	if (matches.length > 1)
	    error("Duplicate Euid: " + euid);
    }
    
}

// end of EuidTest.java

