// NewsIdentifierTest.java - test a NewsIdentifier.
// Copyright (c) 2001 by Reuters PLC.
// $Id: NewsIdentifierTest.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.NewsIdentifier;
import org.newsml.toolkit.NewsMLException;


/**
 * NewsIdentifier-specific conformance tests.
 *
 * <p>This class reports an error if the PublicIdentifier is not
 * properly composed from the other parts of the NewsIdentifier.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see NewsMLTestManager
 */
public class NewsIdentifierTest
    extends TestBase
{

    /**
     * Run tests for a NewsIdentifier node.
     *
     * @param node A NewsIdentifier node.
     * @param useExternal Not used.
     * @exception NewsMLException If the test fails.
     * @exception java.lang.ClassCastException If the node parameter is not
     *   an instance of {@link NewsIdentifier}. 
     * @see TestBase#run
     */
    public void run (BaseNode node, boolean useExternal)
	throws NewsMLException
    {
	NewsIdentifier identifier = (NewsIdentifier)node;
	String id = identifier.getPublicIdentifier().toString();
	StringBuffer id2 = new StringBuffer();
	id2.append("urn:newsml:");
	id2.append(identifier.getProviderId().getName().toString());
	id2.append(':');
	id2.append(identifier.getDateId().toString());
	id2.append(':');
	id2.append(identifier.getNewsItemId().getName().toString());
	id2.append(':');
	id2.append(identifier.getRevisionId().toString());

	String update = identifier.getRevisionId().getUpdate().toString();
	if (!"N".equals(update))
	    id2.append(update);

	if (!id.equals(id2.toString())) 
	    error("Malformed PublicIdentifier: expected \""
		  + id2.toString() + "\" but found \"" + id + '"');
    }

}

// end of NewsIdentifierTest.java
