// NewsItemTest.java - test a NewsItem.
// Copyright (c) 2001 by Reuters PLC.
// $Id: NewsItemTest.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.NewsItem;
import org.newsml.toolkit.NewsMLException;


/**
 * NewsItem-specific conformance tests.
 *
 * <p>This class reports an error if the NewsIdentfier's update is 'A'
 * and a NewsComponent, TopicSet, or Update appears, if the
 * NewsIdentifier's update is 'U' and an Update does not appear, if
 * the NewsIdentifier's update is 'N' and a NewsComponent or TopicSet
 * does not appear, or if the NewsIdentifier's update has any value
 * but 'A', 'U', or 'N'.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see NewsMLTestManager
 */
public class NewsItemTest
    extends TestBase
{

    /**
     * Run tests for a NewsItem node.
     *
     * @param node A NewsItem node.
     * @param useExternal Not used.
     * @exception NewsMLException If the test fails.
     * @exception java.lang.ClassCastException If the node parameter is not
     *   an instance of {@link NewsItem}. 
     * @see TestBase#run
     */
    public void run (BaseNode node, boolean useExternal)
	throws NewsMLException
    {
	NewsItem item = (NewsItem)node;
	String update = item.getIdentification().getNewsIdentifier()
	    .getRevisionId().getUpdate().toString();

	if ("A".equals(update)) {
	    if (item.getRootNewsComponent() != null)
		error("NewsItem has NewsComponent but RevisionId 'A'");
	    else if (item.getRootTopicSet() != null)
		error("NewsItem has TopicSet but RevisionId 'A'");
	    else if (item.getUpdateCount() > 0)
		error("NewsItem has " + item.getUpdateCount()
		      + " Updates but RevisionId 'A'");
	} else if ("U".equals(update)) {
	    if (item.getUpdateCount() < 1)
		error("NewsItem has no Updates but RevisionId 'U'");
	} else if ("N".equals(update)) {
	    if (item.getRootNewsComponent() == null &&
		item.getRootTopicSet() == null)
		error("NewsItem has no NewsComponent or TopicSet but RevisionId 'N'");
	} else {
	    error("Illegal value for RevisionId/@Update: " + update);
	}
    }

}

// end of NewsItemTest.java

