// NewsLineTest.java - test a NewsLine.
// Copyright (c) 2001 by Reuters PLC.
// $Id: NewsLineTest.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.NewsLine;
import org.newsml.toolkit.NewsMLException;


/**
 * NewsLine-specific conformance tests.
 *
 * <p>This class reports an error if a NewsLine contains more than one
 * NewsLineTest child with the same xml:lang value.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see NewsMLTestManager
 */
public class NewsLineTest
    extends TestBase
{

    /**
     * Run tests for a NewsLine node.
     *
     * @param node A NewsLine node.
     * @param useExternal Not used.
     * @exception NewsMLException If the test fails.
     * @exception java.lang.ClassCastException If the node parameter is not
     *   an instance of {@link NewsLine}. 
     * @see TestBase#run
     */
    public void run (BaseNode node, boolean useExternal)
	throws NewsMLException
    {
	NewsLine line = (NewsLine)node;
	int nText = line.getNewsLineTextCount();
	for (int i = 0; i < nText; i++) {
	    String lang;
	    if (line.getNewsLineText(i).getLang() != null)
		lang = line.getNewsLineText(i).getLang().toString();
	    else
		lang = "";
	    for (int j = 0; j < i; j++) {
		String lang2 = line.getNewsLineText(j).getLang().toString();
		if (equals(lang, lang2))
		    error("Duplicate xml:lang value for NewsLineText: "
			  + lang);
	    }
	}
    }


    /**
     * Test two possibly null values for equality.
     *
     * @param o1 The first object to test.
     * @param o2 The second object to test.
     * @return true if the objects are equal (including both null),
     * false otherwise.
     */
    private static boolean equals (Object o1, Object o2)
    {
	return ((o1 == null && o2 == null)
		|| (o1 != null && o1.equals(o2)));
    }

}

// end of NewsLineTest.java
