// PatternTest.java - test text against a regular expression.
// Copyright (c) 2001 by Reuters PLC.
// $Id: PatternTest.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import java.io.IOException;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.NewsMLException;
import org.newsml.toolkit.ProviderId;
import org.newsml.toolkit.Text;


/**
 * Test Text content against a regular expression.
 *
 * <p>This class tests the content of any Text node against a
 * regular expression, and reports an error if the test fails.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see NewsMLTestManager
 */
public class PatternTest
    extends TestBase
{

    /**
     * Construct a new test using the regular expression provided.
     *
     * <p>The regular expression will also serve as the error
     * description; that can be a little cryptic.</p>
     *
     * @param pattern A regular expression.
     */
    public PatternTest (String pattern)
    {
	this(pattern, pattern);
    }


    /**
     * Construct a new test using the regular exp. and description provided.
     *
     * @param pattern A regular expression.
     * @param description A human readable description of the regular
     * expression's purpose.
     */
    public PatternTest (String pattern, String description)
    {
	this.pattern = pattern;
	this.description = description;
    }


    /**
     * Test a pattern against a Text node.
     *
     * @param node A Text node.
     * @param useExternal Not used.
     * @exception NewsMLException If the test fails.
     * @exception java.lang.ClassCastException If the node parameter is not
     *   an instance of {@link Text}. 
     * @see TestBase#run
     */
    public void run (BaseNode node, boolean useExternal)
	throws NewsMLException
    {
				// FIXME: kludge, because FormalName
				// for ProviderId cannot be hit with
				// XPath
	if ("ProviderId".equals(node.getXMLName()))
	    node = ((ProviderId)node).getName();

	if (!Util.matches(pattern, node.toString()))
	    error("Text \"" + node.toString()
		  + "\" does not match constraint '" + description
		  + "': " + node.toString());
    }

    private String pattern;
    private String description;

}

// end of PatternTest.java
