// PropertyTest.java - Property-specific test.
// Copyright (c) 2001 by Reuters PLC.
// $Id: PropertyTest.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import java.io.IOException;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.Property;
import org.newsml.toolkit.NewsMLException;
import org.newsml.toolkit.Text;
import org.newsml.toolkit.Topic;
import org.newsml.toolkit.TopicSet;


/**
 * Test a Property node.
 *
 * <p>This class tests the property's value against the allowed values,
 * if provided.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see NewsMLTestManager
 */
public class PropertyTest
    extends TestBase
{

    /**
     * Run tests for a Property node.
     *
     * @param node A Property node.
     * @param useExternal Not used.
     * @exception NewsMLException If the test fails.
     * @exception java.lang.ClassCastException If the node parameter is not
     *   an instance of {@link Property}. 
     * @see TestBase#run
     */
    public void run (BaseNode node, boolean useExternal)
	throws NewsMLException
    {
	Property prop = (Property)node;
	Text allowedRef = prop.getAllowedValues();
	if (allowedRef != null) {
	    BaseNode target;
	    
	    try {
		target = prop.getSession()
		    .findReference(allowedRef.toString(), useExternal);
	    } catch (IOException e) {
		warning("Exception finding reference " + allowedRef.toString()
			+ ": " + e.getMessage());
		return;
	    }
	    Text value = prop.getValue();
	    if (target != null && value != null) {
		Topic topic;
		try {
		    topic = (((TopicSet)target)
			     .findTopic(value.toString(),
					null, useExternal));
		} catch (IOException e) {
		    warning("Exception finding topic " + value.toString()
			    + ": " + e.getMessage());
		    return;
		}
		if (topic == null)
		    error("Value " + value.toString()
			  + " is not allowed in TopicSet at "
			  + allowedRef.toString());
	    }
		
	}
    }

}

// end of PropertyTest.java

