// ResourceTest.java - test a Resource.
// Copyright (c) 2001 by Reuters PLC.
// $Id: ResourceTest.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.Resource;
import org.newsml.toolkit.NewsMLException;


/**
 * Resource-specific conformance tests.
 *
 * <p>Test that the same URL does not appear twice in a resource.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see NewsMLTestManager
 */
public class ResourceTest
    extends TestBase
{

    /**
     * Run tests for a Resource node.
     *
     * @param node A Resource node.
     * @param useExternal Not used.
     * @exception NewsMLException If the test fails.
     * @exception java.lang.ClassCastException If the node parameter is not
     *   an instance of {@link Resource}. 
     * @see TestBase#run
     */
    public void run (BaseNode node, boolean useExternal)
	throws NewsMLException
    {
	Resource resource = (Resource)node;
	int nUrls = resource.getUrlCount();
	for (int i = 0; i < nUrls; i++) {
	    String ref = resource.getUrl(i).toString();
	    for (int j = 0; j < i; j++) {
		if (ref.equals(resource.getUrl(j).toString())) {
		    warning("Url appears twice: " + ref);
		}
	    }
	}
    }

}

// end of ResourceTest.java

