// RevisionStatusTest.java - test a RevisionStatus.
// Copyright (c) 2001 by Reuters PLC.
// $Id: RevisionStatusTest.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.RevisionStatus;
import org.newsml.toolkit.NewsItem;
import org.newsml.toolkit.NewsMLException;


/**
 * RevisionStatus-specific conformance tests.
 *
 * <p>Test that the status applies to a revision less than the
 * current one.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see NewsMLTestManager
 */
public class RevisionStatusTest
    extends TestBase
{

    /**
     * Run tests for a RevisionStatus node.
     *
     * @param node A RevisionStatus node.
     * @param useExternal Not used.
     * @exception NewsMLException If the test fails.
     * @exception java.lang.ClassCastException If the node parameter is not
     *   an instance of {@link RevisionStatus}. 
     * @see TestBase#run
     */
    public void run (BaseNode node, boolean useExternal)
	throws NewsMLException
    {
	RevisionStatus status = (RevisionStatus)node;
	int id = status.getRevision().toInt();
	int newId = ((NewsItem)(node.getParent().getParent().getParent()))
	    .getIdentification().getNewsIdentifier().getRevisionId().toInt();
	if (id >= newId)
	    error("Old revision id " + id + " is not less than new id "
		  + newId);
    }

}

// end of RevisionStatusTest.java
