// TopicSetTest.java - test a TopicSet.
// Copyright (c) 2001 by Reuters PLC.
// $Id: TopicSetTest.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.FormalNameDecl;
import org.newsml.toolkit.NewsMLException;
import org.newsml.toolkit.Topic;
import org.newsml.toolkit.TopicSet;


/**
 * TopicSet-specific conformance tests.
 *
 * <p>Report an error if two topics have the same formal name and
 * scheme.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see NewsMLTestManager
 */
public class TopicSetTest
    extends TestBase
{

    /**
     * Run tests for a TopicSet node.
     *
     * @param node A TopicSet node.
     * @param useExternal Not used.
     * @exception NewsMLException If the test fails.
     * @exception java.lang.ClassCastException If the node parameter is not
     *   an instance of {@link TopicSet}. 
     * @see TestBase#run
     */
    public void run (BaseNode node, boolean useExternal)
	throws NewsMLException
    {
	TopicSet topicSet = (TopicSet)node;
	Topic topics[] = topicSet.getTopic();
	for (int i = 0; i < topics.length; i++) {
	    for (int j = 0; j < i; j++)
		checkTopics(topics[i], topics[j]);
	}
    }


    /**
     * Test that two topics don't share the same formal name/scheme.
     *
     * @param t1 The first topic to test.
     * @param t2 The second topic to test.
     * @exception NewsMLException if the test fails.
     */
    private void checkTopics (Topic t1, Topic t2)
	throws NewsMLException
    {
	FormalNameDecl decl1[] = t1.getFormalNameDecl();
	FormalNameDecl decl2[] = t2.getFormalNameDecl();
	for (int i = 0; i < decl1.length; i++) {
	    for (int j = 0; j < decl2.length; j++) {
		if (compareDecls(decl1[i], decl2[j]))
		    error("Formal name declared twice in same TopicSet: " +
			  decl1[i].toString() + "/"
			  + decl1[i].getScheme());
	    }
	}
    }


    /**
     * Compare two formal name declarations.
     *
     * @param decl1 The first declaration to compare.
     * @param decl2 The second declaration to compare.
     * @return true if the declarations are equivalent.
     */
    private static boolean compareDecls (FormalNameDecl decl1,
					 FormalNameDecl decl2)
    {
	return (equals(decl1.toString(), decl2.toString()) &&
		equals(decl1.getScheme(), decl2.getScheme()));
    }


    /**
     * Test two possibly-null objects for equality.
     *
     * @param o1 The first object to test.
     * @param o2 The second object to test.
     * @return true of the objects are equal or both null, false
     * otherwise.
     */
    private static boolean equals (Object o1, Object o2)
    {
	return ((o1 == null && o2 == null) ||
		(o1 != null && o1.equals(o2)));
    }

}

// end of TopicSetTest.java

