// TopicUseTest.java - test a TopicUse.
// Copyright (c) 2001 by Reuters PLC.
// $Id: TopicUseTest.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.conformance;

import java.io.IOException;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.NewsMLException;
import org.newsml.toolkit.Text;
import org.newsml.toolkit.TopicUse;


/**
 * TopicUse-specific conformance tests.
 *
 * <p>Report a warning if the TopicUse does not apply to any nodes.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see NewsMLTestManager
 */
public class TopicUseTest
    extends TestBase
{

    /**
     * Run tests for a TopicUse node.
     *
     * @param node A TopicUse node.
     * @param useExternal Not used.
     * @exception NewsMLException If the test fails.
     * @exception java.lang.ClassCastException If the node parameter is not
     *   an instance of {@link TopicUse}. 
     * @see TestBase#run
     */
    public void run (BaseNode node, boolean useExternal)
	throws NewsMLException
    {
	Text xpath = ((TopicUse)node).getContext();
	if (xpath == null)
	    return;

				// Use the parent of the parent Catalog
	BaseNode context = node.getParent().getParent();
	BaseNode matches[];
	try {
	    matches =
		node.getSession().getNodesByXPath(context, xpath.toString());
	} catch (IOException e) {
	    throw new NewsMLException(e);
	}
	if (matches.length == 0)
	    warning("No match for TopicUse xpath: " + xpath);
    }

}

// end of TopicUseTest.java
