// DOMAdministrativeMetadata - DOM implementation of AdministrativeMetadata.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC
// $Id: DOMAdministrativeMetadata.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.AdministrativeMetadata;
import org.newsml.toolkit.Catalog;
import org.newsml.toolkit.IdText;
import org.newsml.toolkit.PartyList;
import org.newsml.toolkit.Property;
import org.newsml.toolkit.SourceList;


/**
 * DOM implementation of AdministrativeMetadata.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMAdministrativeMetadata
    extends DOMBaseNode
    implements AdministrativeMetadata
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the metadata.
     */
    protected DOMAdministrativeMetadata (Node element,
					 DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see AdministrativeMetadata#getFileName()
     */
    public IdText getFileName ()
    {
	return (IdText)getChild("FileName", 0);
    }


    /**
     * @see AdministrativeMetadata#getSystemIdentifier()
     */
    public IdText getSystemIdentifier ()
    {
	return (IdText)getChild("SystemIdentifier", 0);
    }


    /**
     * @see AdministrativeMetadata#getProvider()
     */
    public PartyList getProvider ()
    {
	return (PartyList)getChild("Provider", 0);
    }


    /**
     * @see AdministrativeMetadata#getCreator()
     */
    public PartyList getCreator ()
    {
	return (PartyList)getChild("Creator", 0);
    }


    /**
     * @see AdministrativeMetadata#getSourceCount()
     */
    public int getSourceCount ()
    {
	return getChildCount("Source");
    }


    /**
     * @see AdministrativeMetadata#getSource(int)
     */
    public SourceList getSource (int index)
    {
	return (SourceList)getChild("Source", index);
    }


    /**
     * @see AdministrativeMetadata#getSource()
     */
    public SourceList [] getSource ()
    {
	int len = getSourceCount();
	SourceList ret[] = new SourceList[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getSource(i);
	return ret;
    }


    /**
     * @see AdministrativeMetadata#getContributorCount()
     */
    public int getContributorCount ()
    {
	return getChildCount("Contributor");
    }


    /**
     * @see AdministrativeMetadata#getContributor(int)
     */
    public PartyList getContributor (int index)
    {
	return (PartyList)getChild("Contributor", index);
    }


    /**
     * @see AdministrativeMetadata#getContributor()
     */
    public PartyList [] getContributor ()
    {
	int len = getContributorCount();
	PartyList ret[] = new PartyList[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getContributor(i);
	return ret;
    }

}

// end of DOMAdministrativeMetadata.java
