// DOMCatalog.java - DOM implementation of Catalog.
// Copyright (c) 2001 by Reuters PLC.

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import java.io.IOException;

import org.w3c.dom.Node;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.Catalog;
import org.newsml.toolkit.NewsMLException;
import org.newsml.toolkit.Resource;
import org.newsml.toolkit.Text;
import org.newsml.toolkit.TopicUse;


/**
 * DOM implementation of Catalog.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMCatalog
    extends DOMBaseNode
    implements Catalog
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the basis for choice.
     */
    protected DOMCatalog (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see Catalog#getResourceCount()
     */
    public int getResourceCount ()
    {
	return getChildCount("Resource");
    }


    /**
     * @see Catalog#getResource(int)
     */
    public Resource getResource (int index)
    {
	return (Resource)getChild("Resource", index);
    }


    /**
     * @see Catalog#getResource()
     */
    public Resource [] getResource ()
    {
	int len = getResourceCount();
	Resource ret[] = new Resource[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getResource(i);
	return ret;
    }


    /**
     * @see Catalog#getTopicUseCount()
     */
    public int getTopicUseCount ()
    {
	return getChildCount("TopicUse");
    }


    /**
     * @see Catalog#getTopicUse(int)
     */
    public TopicUse getTopicUse (int index)
    {
	return (TopicUse)getChild("TopicUse", index);
    }


    /**
     * @see Catalog#getTopicUse()
     */
    public TopicUse [] getTopicUse ()
    {
	int len = getTopicUseCount();
	TopicUse ret[] = new TopicUse[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getTopicUse(i);
	return ret;
    }


    /**
     * @see Catalog#getReferencedCatalog
     */
    public Catalog getReferencedCatalog (boolean useExternal)
	throws IOException
    {
	Text href = getHref();

				// If there's no Href attribute,
				// then this is the final
				// referenced catalog.
	if (href == null) {
	    return this;
	} 

	else {
				// FIXME: check for loops
	    BaseNode node = getSession().findReference(href.toString(),
						       useExternal);
	    if (node == null)
		return null;
	    else if (!"Catalog".equals(node.getXMLName()))
		throw new NewsMLException("external catalog "
					  + href
					  + " has root element "
					  + node.getXMLName()
					  +" (expected Catalog)");
	    else
		return ((Catalog)node).getReferencedCatalog(useExternal);
	}
    }

}

// end of DOMCatalog.java
