// DOMContentItem.java - DOM implementation of ContentItem.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC
// $Id: DOMContentItem.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import org.newsml.toolkit.Catalog;
import org.newsml.toolkit.Characteristics;
import org.newsml.toolkit.Comment;
import org.newsml.toolkit.ContentItem;
import org.newsml.toolkit.DataContent;
import org.newsml.toolkit.Encoding;
import org.newsml.toolkit.FormalName;


/**
 * DOM implementation of ContentItem
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMContentItem
    extends DOMBaseNode
    implements ContentItem
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the content item.
     */
    protected DOMContentItem (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see ContentItem#getMediaType()
     */
    public FormalName getMediaType ()
    {
	return (FormalName)getChild("MediaType", 0);
    }


    /**
     * @see ContentItem#getFormat()
     */
    public FormalName getFormat ()
    {
	return (FormalName)getChild("Format", 0);
    }


    /**
     * @see ContentItem#getMimeType()
     */
    public FormalName getMimeType ()
    {
	return (FormalName)getChild("MimeType", 0);
    }


    /**
     * @see ContentItem#getNotation()
     */
    public FormalName getNotation ()
    {
	return (FormalName)getChild("Notation", 0);
    }


    /**
     * @see ContentItem#getCharacteristics()
     */
    public Characteristics getCharacteristics ()
    {
	return (Characteristics)getChild("Characteristics", 0);
    }


    /**
     * @see ContentItem#getEncoding
     */
    public Encoding getEncoding ()
    {
	return (Encoding)getChild("Encoding", 0);
    }


    /**
     * @see ContentItem#getDataContent
     */
    public DataContent getDataContent ()
    {
	return (DataContent)getChild("DataContent", 0);
    }

}

// end of DOMContentItem.java
