// DOMDataContent.java - DOM implementation of DataContent.
// Copyright (c) 2001 by Reuters PLC
// $Id: DOMDataContent.java,v 1.6 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import java.io.IOException;
import java.io.StringWriter;

import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import org.newsml.toolkit.DataContent;


/**
 * DOM implementation of DataContent.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMDataContent
    extends DOMBaseNode
    implements DataContent
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the data content.
     */
    protected DOMDataContent (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see DataContent#getDOMNodes
     */
    public NodeList getDOMNodes ()
    {
	return getDOMNode().getChildNodes();
    }


    /**
     * @see DataContent#getText
     */
    public String getText ()
    {
	return DOMUtils.getText(getDOMNode());
    }


    /**
     * @see DataContent#getXMLString
     */
    public String getXMLString ()
    {
	StringWriter writer = new StringWriter();
	NodeList children = getDOMNode().getChildNodes();
	int length = children.getLength();
	for (int i = 0; i < length; i++) {
	    try {
		DOMUtils.writeNode(children.item(i), writer, false,
				   null, null);
	    } catch (IOException e) {
		throw new RuntimeException("Internal IO exception");
	    }
	}
	return writer.toString();
    }

}

// end of DOMDataContent.java
