// DOMDelta.java - DOM implementation of Delta.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMDelta.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.Delta;
import org.newsml.toolkit.Text;


/**
 * DOM implementation of Delta.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMDelta
    extends DOMBaseNode
    implements Delta
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the delta.
     */
    protected DOMDelta (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }

    
    /**
     * @see Delta#getAction
     */
    public int getAction ()
    {
	String name = getXMLName().intern();
	if ("InsertBefore" == name) {
	    return INSERT_BEFORE;
	} else if ("InsertAfter" == name) {
	    return INSERT_AFTER;
	} else if ("Replace" == name) {
	    return REPLACE;
	} else if ("Delete" == name) {
	    return DELETE;
	} else {
	    throw new RuntimeException("Unexpected delta name: " + name);
	}
    }


    /**
     * @see Delta#getTargetRef
     */
    public Text getTargetRef ()
    {
	return getAttribute("DuidRef");
    }


    /**
     * @see Delta#getTargetNode
     */
    public BaseNode getTargetNode ()
    {
	return getSession().getNodeByDuid(getTargetRef().toString());
    }

}

// end of DOMDelta.java
