// DescriptiveMetadata.java - DOM implementation of DescriptiveMetadata.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMDescriptiveMetadata.java,v 1.7 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.AssignedFormalName;
import org.newsml.toolkit.AssignedText;
import org.newsml.toolkit.DescriptiveMetadata;
import org.newsml.toolkit.OfInterestTo;
import org.newsml.toolkit.SubjectCode;
import org.newsml.toolkit.TopicOccurrence;


/**
 * DOM implementation of DescriptiveMetadata.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMDescriptiveMetadata
    extends DOMBaseNode
    implements DescriptiveMetadata
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the descriptive metadata.
     */
    protected DOMDescriptiveMetadata (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see DescriptiveMetadata#getLanguageCount()
     */
    public int getLanguageCount ()
    {
	return getChildCount("Language");
    }


    /**
     * @see DescriptiveMetadata#getLanguage(int)
     */
    public AssignedFormalName getLanguage (int index)
    {
	return (AssignedFormalName)getChild("Language", index);
    }


    /**
     * @see DescriptiveMetadata#getLanguage()
     */
    public AssignedFormalName [] getLanguage ()
    {
	int len = getLanguageCount();
	AssignedFormalName ret[] = new AssignedFormalName[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getLanguage(i);
	return ret;
    }


    /**
     * @see DescriptiveMetadata#getGenre()
     */
    public AssignedFormalName getGenre ()
    {
	return (AssignedFormalName)getChild("Genre", 0);
    }


    /**
     * @see DescriptiveMetadata#getSubjectCodeCount()
     */
    public int getSubjectCodeCount ()
    {
	return getChildCount("SubjectCode");
    }


    /**
     * @see DescriptiveMetadata#getSubjectCode(int)
     */
    public SubjectCode getSubjectCode (int index)
    {
	return (SubjectCode)getChild("SubjectCode", index);
    }


    /**
     * @see DescriptiveMetadata#getSubjectCode()
     */
    public SubjectCode [] getSubjectCode ()
    {
	int len = getSubjectCodeCount();
	SubjectCode ret[] = new SubjectCode[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getSubjectCode(i);
	return ret;
    }


    /**
     * @see DescriptiveMetadata#getOfInterestToCount()
     */
    public int getOfInterestToCount ()
    {
	return getChildCount("OfInterestTo");
    }


    /**
     * @see DescriptiveMetadata#getOfInterestTo(int)
     */
    public OfInterestTo getOfInterestTo (int index)
    {
	return (OfInterestTo)getChild("OfInterestTo", index);
    }


    /**
     * @see DescriptiveMetadata#getOfInterestTo()
     */
    public OfInterestTo [] getOfInterestTo ()
    {
	int len = getOfInterestToCount();
	OfInterestTo ret[] = new OfInterestTo[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getOfInterestTo(i);
	return ret;
    }


    /**
     * @see DescriptiveMetadata#getTopicOccurrenceCount()
     */
    public int getTopicOccurrenceCount ()
    {
	return getChildCount("TopicOccurrence");
    }


    /**
     * @see DescriptiveMetadata#getTopicOccurrence(int)
     */
    public TopicOccurrence getTopicOccurrence (int index)
    {
	return (TopicOccurrence)getChild("TopicOccurrence", index);
    }


    /**
     * @see AdministrativeMetadata#getTopicOccurrence()
     */
    public TopicOccurrence [] getTopicOccurrence ()
    {
	int len = getTopicOccurrenceCount();
	TopicOccurrence ret[] = new TopicOccurrence[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getTopicOccurrence(i);
	return ret;
    }

}

// end of DOMDescriptiveMetadata.java
