// DOMFactory.java - shared interface for creating DOM nodes.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC
// $Id: DOMFactory.java,v 1.7 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import java.io.IOException;
import java.io.Reader;

import org.xml.sax.SAXException;

import org.w3c.dom.Document;


/**
 * Shared interface for creating DOM nodes.
 *
 * <p>This interface allows different DOM libraries to be used
 * with the NewsMLExplorer; an application should implement
 * this interface to create a DOM tree from a URL string using
 * the techniques of a specific DOM library.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
public interface DOMFactory
{

    /**
     * Require or forbid DTD validation.
     *
     * @param validation true to require DTD validation, false to forbid it.
     * @exception IOException if the implementation does not support
     * the requested state.
     * @see org.newsml.toolkit.NewsMLFactory#setValidation(boolean)
     */
    public void setValidation (boolean validation)
	throws IOException;


    /**
     * Get the current validation state.
     *
     * @return true if the DOM factory will perform DTD validation, false
     * if it will not.
     */
    public boolean getValidation ();


    /**
     * Construct a DOM package from the URL provided.
     *
     * @param url A string containing an absolute URL pointing to
     * an XML document.
     * @return a DOM document from the URL (not null).
     * @exception IOException If there is an error reading the
     * document.
     */
    public Document createDOM (String url)
	throws IOException;


    /**
     * Construct a DOM package from the URL provided.
     *
     * @param input A character stream containing an XML document.
     * @param baseUrl A string containing an absolute URL, to use for 
     * resolving external entity references.
     * @return a DOM document from the character stream (not null).
     * @exception IOException If there is an error reading the
     * document.
     */
    public Document createDOM (Reader input, String baseURL)
	throws IOException;

}

// end of DOMFactory.java
