// DOMIdentification.java - DOM implementation of Identification.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMIdentification.java,v 1.5 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.Identification;
import org.newsml.toolkit.IdText;
import org.newsml.toolkit.Label;
import org.newsml.toolkit.NewsIdentifier;


/**
 * DOM implementation of Identification
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMIdentification
    extends DOMBaseNode
    implements Identification
{

    /**
     * Constructor.
     */
    public DOMIdentification (Node e, DOMNewsMLSession session)
    {
	super(e, session);
    }


    /**
     * @see Identification.getNewsIdentifier()
     */
    public NewsIdentifier getNewsIdentifier ()
    {
	return (NewsIdentifier)getChild("NewsIdentifier", 0);
    }


    /**
     * @see Identification.getNameLabel()
     */
    public IdText getNameLabel ()
    {
	return (IdText)getChild("NameLabel", 0);
    }


    /**
     * @see Identification.getDateLabel()
     */
    public IdText getDateLabel ()
    {
	return (IdText)getChild("DateLabel", 0);
    }


    /**
     * @see Identification.getLabelCount()
     */
    public int getLabelCount ()
    {
	return getChildCount("Label");
    }


    /**
     * @see Identification.getLabel(int)
     */
    public Label getLabel (int index)
    {
	return (Label)getChild("Label", index);
    }


    /**
     * @see Identification.getLabel()
     */
    public Label [] getLabel ()
    {
	int len = getLabelCount();
	Label ret[] = new Label[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getLabel(i);
	return ret;
    }

}

// end of DOMIdentification.java
