// DOMNewsEnvelope.java - DOM implementation of NewsEnvelope.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMNewsEnvelope.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.FormalName;
import org.newsml.toolkit.IdText;
import org.newsml.toolkit.NewsEnvelope;
import org.newsml.toolkit.PartyList;
import org.newsml.toolkit.TransmissionId;


/**
 * DOM implementation of NewsEnvelope.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMNewsEnvelope
    extends DOMBaseNode
    implements NewsEnvelope
{


    /**
     * Constructor.
     *
     * @param element The DOM node representing the news envelope.
     */
    protected DOMNewsEnvelope (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see NewsEnvelope#getTransmissionId()
     */
    public TransmissionId getTransmissionId ()
    {
	return (TransmissionId)getChild("TransmissionId", 0);
    }


    /**
     * @see NewsEnvelope#getSentFrom()
     */
    public PartyList getSentFrom ()
    {
	return (PartyList)getChild("SentFrom", 0);
    }


    /**
     * @see NewsEnvelope#getSentTo()
     */
    public PartyList getSentTo ()
    {
	return (PartyList)getChild("SentTo", 0);
    }


    /**
     * @see NewsEnvelope#getDateAndTime()
     */
    public IdText getDateAndTime ()
    {
	return (IdText)getChild("DateAndTime", 0);
    }


    /**
     * @see NewsEnvelope#getNewsServiceCount()
     */
    public int getNewsServiceCount ()
    {
	return getChildCount("NewsService");
    }


    /**
     * @see NewsEnvelope#getNewsService(int)
     */
    public FormalName getNewsService (int index)
    {
	return (FormalName)getChild("NewsService", index);
    }


    /**
     * @see NewsEnvelope#getNewsService()
     */
    public FormalName [] getNewsService ()
    {
	int len = getNewsServiceCount();
	FormalName ret[] = new FormalName[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getNewsService(i);
	return ret;
    }


    /**
     * @see NewsEnvelope#getNewsProductCount()
     */
    public int getNewsProductCount ()
    {
	return getChildCount("NewsProduct");
    }


    /**
     * @see NewsEnvelope#getNewsProduct(int)
     */
    public FormalName getNewsProduct (int index)
    {
	return (FormalName)getChild("NewsProduct", index);
    }


    /**
     * @see NewsEnvelope#getNewsProduct()
     */
    public FormalName [] getNewsProduct ()
    {
	int len = getNewsProductCount();
	FormalName ret[] = new FormalName[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getNewsProduct(i);
	return ret;
    }


    /**
     * @see NewsEnvelope#getPriority()
     */
    public FormalName getPriority ()
    {
	return (FormalName)getChild("Priority", 0);
    }

}

// end of DOMNewsEnvelope.java

