// DOMNewsIdentifier.java - DOM implementation of NewsIdentifier.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMNewsIdentifier.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.FormalName;
import org.newsml.toolkit.NewsIdentifier;
import org.newsml.toolkit.NewsItemId;
import org.newsml.toolkit.ProviderId;
import org.newsml.toolkit.RevisionId;
import org.newsml.toolkit.Text;


/**
 * DOM implementation of NewsIdentifier.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMNewsIdentifier
    extends DOMBaseNode
    implements NewsIdentifier
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the news identifier.
     */
    protected DOMNewsIdentifier (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see NewsIdentifier#getProviderId()
     */
    public ProviderId getProviderId ()
    {
	return (ProviderId)getChild("ProviderId", 0);
    }


    /**
     * @see NewsIdentifier#getDateId()
     */
    public Text getDateId ()
    {
	return (Text)getChild("DateId", 0);
    }


    /**
     * @see NewsIdentifier#getNewsItemId()
     */
    public NewsItemId getNewsItemId ()
    {
	return (NewsItemId)getChild("NewsItemId", 0);
    }


    /**
     * @see NewsIdentifier#getRevisionId()
     */
    public RevisionId getRevisionId ()
    {
	return (RevisionId)getChild("RevisionId", 0);
    }


    /**
     * @see NewsIdentifier#getPublicIdentifier()
     */
    public Text getPublicIdentifier ()
    {
	return (Text)getChild("PublicIdentifier", 0);
    }

}

// end of DOMNewsIdentifier.java
