// DOMNewsIdentifier.java - DOM implementation of NewsIdentifier.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMNewsIdentifierFormalName.java,v 1.5 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.NewsItemId;
import org.newsml.toolkit.ProviderId;
import org.newsml.toolkit.Text;


/**
 * Formal name for news identifier parts.
 *
 * <p>News identifiers have vocabulary- and scheme-qualified
 * names, but with a different type of markup (the local name
 * part is represented by character data content rather than
 * a Name attribute).  This class hides the differences from
 * applications.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMNewsIdentifierFormalName
    extends DOMFormalName
    implements NewsItemId, ProviderId
{

    /**
     * Constructor.
     *
     * @param element The DOM node containing the formal name
     * information.
     */
    protected DOMNewsIdentifierFormalName (Node element,
					   DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see FormalName#getName()
     */
    public Text getName ()
    {
	return new DOMText(getDOMNode(), session);
    }

}

// end of DOMNewsIdentifierFormalName.java
