// DOMNewsItem.java - DOM implementation of NewsItem.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMNewsItem.java,v 1.9 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.FormalName;
import org.newsml.toolkit.Identification;
import org.newsml.toolkit.Label;
import org.newsml.toolkit.NewsComponent;
import org.newsml.toolkit.NewsIdentifier;
import org.newsml.toolkit.NewsItem;
import org.newsml.toolkit.NewsManagement;
import org.newsml.toolkit.Text;
import org.newsml.toolkit.TopicSet;
import org.newsml.toolkit.Update;


/**
 * DOM implementation of NewsItem.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMNewsItem
    extends DOMBaseNode
    implements NewsItem
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the news item.
     */
    protected DOMNewsItem (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see NewsItem#getIdentification()
     */
    public Identification getIdentification ()
    {
	return (Identification)getChild("Identification", 0);
    }


    /**
     * @see NewsItem#getNewsManagement()
     */
    public NewsManagement getNewsManagement ()
    {
	return (NewsManagement)getChild("NewsManagement", 0);
    }


    /**
     * @see NewsItem#getRootNewsComponent()
     */
    public NewsComponent getRootNewsComponent ()
    {
	return (NewsComponent)getChild("NewsComponent", 0);
    }


    /**
     * @see NewsItem#getRootTopicSet()
     */
    public TopicSet getRootTopicSet ()
    {
	return (TopicSet)getChild("TopicSet", 0);
    }


    /**
     * @see NewsItem#getUpdateCount()
     */
    public int getUpdateCount ()
    {
	return getChildCount("Update");
    }


    /**
     * @see NewsItem#getUpdate(int)
     */
    public Update getUpdate (int index)
    {
	return (Update)getChild("Update", index);
    }


    /**
     * @see NewsItem#getUpdate()
     */
    public Update [] getUpdate ()
    {
	int nUpdates = getUpdateCount();
	Update updates[] = new Update[nUpdates];
	for (int i = 0; i < nUpdates; i++)
	    updates[i] = getUpdate(i);
	return updates;
    }

}

// end of DOMNewsItem.java
