// DOMNewsItemRef.java - DOM implementation of NewsItemRef.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: DOMNewsItemRef.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $
// Copyright (c) 2001 by Reuters PLC.

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import java.io.IOException;

import org.w3c.dom.Node;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.NewsItem;
import org.newsml.toolkit.NewsItemRef;
import org.newsml.toolkit.NewsML;
import org.newsml.toolkit.NewsMLException;
import org.newsml.toolkit.Text;


/**
 * DOM implementation of NewsItemRef.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMNewsItemRef
    extends DOMBaseNode
    implements NewsItemRef
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the news item reference.
     */
    protected DOMNewsItemRef (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see NewsItemRef#getRef()
     */
    public Text getRef ()
    {
	return getAttribute("NewsItem");
    }


    /**
     * @see NewsItemRef#getReferencedNewsItem(boolean)
     */
    public NewsItem getReferencedNewsItem (boolean useExternal)
	throws IOException
    {
	String ref = getRef().toString();
	if (ref == null)
	    return null;
	BaseNode node = getSession().findReference(ref, useExternal);
	if (node == null)
	    return null;
	else if ("NewsItem".equals(node.getXMLName()))
	    return (NewsItem)node;
	else if ("NewsML".equals(node.getXMLName()))
	    return ((NewsML)node).getNewsItem(0);
	else
	    throw new NewsMLException("External NewsItem "
				      + ref
				      + " has unsupported root element type "
				      + node.getXMLName()
				      + " (must be NewsML or NewsItem)");
    }

}

// end of DOMNewsItemRef.java
