// DOMNewsLine.java - DOM implementation of NewsLine.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMNewsLine.java,v 1.7 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.FormalName;
import org.newsml.toolkit.NewsLine;
import org.newsml.toolkit.OriginText;


/**
 * DOM implementation of NewsLine.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMNewsLine
    extends DOMBaseNode
    implements NewsLine
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the news line.
     */
    protected DOMNewsLine (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see NewsLine#getNewsLineType()
     */
    public FormalName getNewsLineType ()
    {
	return (FormalName)getChild("NewsLineType", 0);
    }


    /**
     * @see NewsLine#getNewsLineTextCount()
     */
    public int getNewsLineTextCount ()
    {
	return getChildCount("NewsLineText");
    }


    /**
     * @see NewsLine#getNewsLineText(int)
     */
    public OriginText getNewsLineText (int index)
    {
	return (OriginText)getChild("NewsLineText", index);
    }


    /**
     * @see NewsLine#getNewsLineText()
     */
    public OriginText [] getNewsLineText ()
    {
	int len = getNewsLineTextCount();
	OriginText ret[] = new OriginText[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getNewsLineText(i);
	return ret;
    }

}

// end of DOMNewsLine.java
