// DOMNewsLines.java - DOM implementation of NewsLines.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMNewsLines.java,v 1.7 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import org.newsml.toolkit.HeadLineGroup;
import org.newsml.toolkit.NewsLine;
import org.newsml.toolkit.NewsLines;
import org.newsml.toolkit.NewsMLSession;
import org.newsml.toolkit.OriginText;


/**
 * DOM implementation of NewsLines.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMNewsLines
    extends DOMBaseNode
    implements NewsLines
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the element.
     */
    protected DOMNewsLines (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see NewsLines#getHeadLineGroupCount()
     */
    public int getHeadLineGroupCount ()
    {
	return getChildCount("HeadLine");
    }


    /**
     * @see NewsLines#getHeadLineGroup(int)
     */
    public HeadLineGroup getHeadLineGroup (int index)
    {
	NodeList nodes = getDOMNode().getChildNodes();
	int pos = DOMUtils.findPos(nodes, "HeadLine", index);

	if (pos > -1) {
	    OriginText headline = null;
	    OriginText subheadline = null;
	    Node n1 = nodes.item(pos); // headline
	    headline = new DOMOriginBase(n1, session);
	    Node n2;		// possible subheadline
	    while (++pos < nodes.getLength()) {
		n2 = nodes.item(pos);
				// scan to next element only
		if (n2.getNodeType() == Node.ELEMENT_NODE) {
		    if ("SubHeadLine".equals(n2.getNodeName()))
			subheadline = new DOMOriginBase(n2, session);
		    else
			break;
		}
	    }
	    return new DOMHeadLineGroup(headline, subheadline);
	} else {
	    return null;
	}
    }


    /**
     * @see NewsLines#getHeadLineGroup()
     */
    public HeadLineGroup [] getHeadLineGroup ()
    {
	int len = getHeadLineGroupCount();
	HeadLineGroup ret[] = new HeadLineGroup[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getHeadLineGroup(i);
	return ret;
    }


    /**
     * @see NewsLines#getHeadLineCount()
     */
    public int getHeadLineCount ()
    {
	return getChildCount("HeadLine");
    }


    /**
     * @see NewsLines#getHeadLine(int)
     */
    public OriginText getHeadLine (int index)
    {
	return (OriginText)getChild("HeadLine", index);
    }


    /**
     * @see NewsLines#getHeadLine()
     */
    public OriginText [] getHeadLine ()
    {
	int len = getHeadLineCount();
	OriginText ret[] = new OriginText[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getHeadLine(i);
	return ret;
    }


    /**
     * @see NewsLines#getSubHeadLineCount()
     */
    public int getSubHeadLineCount ()
    {
	return getChildCount("SubHeadLine");
    }


    /**
     * @see NewsLines#getSubHeadLine(int)
     */
    public OriginText getSubHeadLine (int index)
    {
	return (OriginText)getChild("SubHeadLine", index);
    }


    /**
     * @see NewsLines#getSubHeadLine()
     */
    public OriginText [] getSubHeadLine ()
    {
	int len = getSubHeadLineCount();
	OriginText ret[] = new OriginText[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getSubHeadLine(i);
	return ret;
    }


    /**
     * @see NewsLines#getByLineCount()
     */
    public int getByLineCount ()
    {
	return getChildCount("ByLine");
    }


    /**
     * @see NewsLines#getByLine(int)
     */
    public OriginText getByLine (int index)
    {
	return (OriginText)getChild("ByLine", index);
    }


    /**
     * @see NewsLines#getByLine()
     */
    public OriginText [] getByLine ()
    {
	int len = getByLineCount();
	OriginText ret[] = new OriginText[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getByLine(i);
	return ret;
    }


    /**
     * @see NewsLines#getDateLineCount()
     */
    public int getDateLineCount ()
    {
	return getChildCount("DateLine");
    }


    /**
     * @see NewsLines#getDateLine(int)
     */
    public OriginText getDateLine (int index)
    {
	return (OriginText)getChild("DateLine", index);
    }


    /**
     * @see NewsLines#getDateLine()
     */
    public OriginText [] getDateLine ()
    {
	int len = getDateLineCount();
	OriginText ret[] = new OriginText[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getDateLine(i);
	return ret;
    }


    /**
     * @see NewsLines#getCreditLineCount()
     */
    public int getCreditLineCount ()
    {
	return getChildCount("CreditLine");
    }


    /**
     * @see NewsLines#getCreditLine(int)
     */
    public OriginText getCreditLine (int index)
    {
	return (OriginText)getChild("CreditLine", index);
    }


    /**
     * @see NewsLines#getCreditLine()
     */
    public OriginText [] getCreditLine ()
    {
	int len = getCreditLineCount();
	OriginText ret[] = new OriginText[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getCreditLine(i);
	return ret;
    }


    /**
     * @see NewsLines#getCopyrightLineCount()
     */
    public int getCopyrightLineCount ()
    {
	return getChildCount("CopyrightLine");
    }


    /**
     * @see NewsLines#getCopyrightLine(int)
     */
    public OriginText getCopyrightLine (int index)
    {
	return (OriginText)getChild("CopyrightLine", index);
    }


    /**
     * @see NewsLines#getCopyrightLine()
     */
    public OriginText [] getCopyrightLine ()
    {
	int len = getCopyrightLineCount();
	OriginText ret[] = new OriginText[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getCopyrightLine(i);
	return ret;
    }


    /**
     * @see NewsLines#getRightsLineCount()
     */
    public int getRightsLineCount ()
    {
	return getChildCount("RightsLine");
    }


    /**
     * @see NewsLines#getRightsLine(int)
     */
    public OriginText getRightsLine (int index)
    {
	return (OriginText)getChild("RightsLine", index);
    }


    /**
     * @see NewsLines#getRightsLine()
     */
    public OriginText [] getRightsLine ()
    {
	int len = getRightsLineCount();
	OriginText ret[] = new OriginText[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getRightsLine(i);
	return ret;
    }


    /**
     * @see NewsLines#getSeriesLineCount()
     */
    public int getSeriesLineCount ()
    {
	return getChildCount("SeriesLine");
    }


    /**
     * @see NewsLines#getSeriesLine(int)
     */
    public OriginText getSeriesLine (int index)
    {
	return (OriginText)getChild("SeriesLine", index);
    }


    /**
     * @see NewsLines#getSeriesLine()
     */
    public OriginText [] getSeriesLine ()
    {
	int len = getSeriesLineCount();
	OriginText ret[] = new OriginText[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getSeriesLine(i);
	return ret;
    }


    /**
     * @see NewsLines#getSlugLineCount()
     */
    public int getSlugLineCount ()
    {
	return getChildCount("SlugLine");
    }


    /**
     * @see NewsLines#getSlugLine(int)
     */
    public OriginText getSlugLine (int index)
    {
	return (OriginText)getChild("SlugLine", index);
    }


    /**
     * @see NewsLines#getSlugLine()
     */
    public OriginText [] getSlugLine ()
    {
	int len = getSlugLineCount();
	OriginText ret[] = new OriginText[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getSlugLine(i);
	return ret;
    }


    /**
     * @see NewsLines#getKeywordLineCount()
     */
    public int getKeywordLineCount ()
    {
	return getChildCount("KeywordLine");
    }


    /**
     * @see NewsLines#getKeywordLine(int)
     */
    public OriginText getKeywordLine (int index)
    {
	return (OriginText)getChild("KeywordLine", index);
    }


    /**
     * @see NewsLines#getKeywordLine()
     */
    public OriginText [] getKeywordLine ()
    {
	int len = getKeywordLineCount();
	OriginText ret[] = new OriginText[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getKeywordLine(i);
	return ret;
    }


    /**
     * @see NewsLines#getNewsLineCount()
     */
    public int getNewsLineCount ()
    {
	return getChildCount("NewsLine");
    }


    /**
     * @see NewsLines#getNewsLine(int)
     */
    public NewsLine getNewsLine (int index)
    {
	return (NewsLine)getChild("NewsLine", index);
    }


    /**
     * @see NewsLines#getNewsLine()
     */
    public NewsLine [] getNewsLine ()
    {
	int len = getNewsLineCount();
	NewsLine ret[] = new NewsLine[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getNewsLine(i);
	return ret;
    }


    /**
     * Inner class implementing HeadLineGroup.
     */
    class DOMHeadLineGroup
	implements HeadLineGroup
    {

	/**
	 * Constructor.
	 */
	DOMHeadLineGroup (OriginText headline, OriginText subheadline)
	{
	    this.headline = headline;
	    this.subheadline = subheadline;
	}


	/**
	 * @see HeadLineGroup#getHeadLine()
	 */
	public OriginText getHeadLine ()
	{
	    return headline;
	}


	/**
	 * @see HeadLineGroup#getSubHeadLine
	 */
	public OriginText getSubHeadLine ()
	{
	    return subheadline;
	}

	private OriginText headline;
	private OriginText subheadline;

    }

}

// end of DOMNewsLines.java
