// DOMNewsML.java - DOM implementation of NewsML.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMNewsML.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Document;
import org.w3c.dom.Node;

import org.newsml.toolkit.NewsEnvelope;
import org.newsml.toolkit.NewsItem;
import org.newsml.toolkit.NewsML;
import org.newsml.toolkit.TopicSet;


/**
 * DOM implementation of NewsML.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMNewsML
    extends DOMBaseNode
    implements NewsML
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the NewsML package.
     */
    public DOMNewsML (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see NewsML#getTopicSetCount()
     */
    public int getTopicSetCount ()
    {
	return getChildCount("TopicSet");
    }


    /**
     * @see NewsML#getTopicSet(int)
     */
    public TopicSet getTopicSet (int index)
    {
	return (TopicSet)getChild("TopicSet", index);
    }


    /**
     * @see NewsML#getTopicSet()
     */
    public TopicSet [] getTopicSet ()
    {
	int len = getTopicSetCount();
	TopicSet ret[] = new TopicSet[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getTopicSet(i);
	return ret;
    }


    /**
     * @see NewsML#getNewsEnvelope()
     */
    public NewsEnvelope getNewsEnvelope ()
    {
	return (NewsEnvelope)getChild("NewsEnvelope", 0);
    }


    /**
     * @see NewsML#getNewsItemCount()
     */
    public int getNewsItemCount ()
    {
	return getChildCount("NewsItem");
    }


    /**
     * @see NewsML#getNewsItem(int)
     */
    public NewsItem getNewsItem (int index)
    {
	return (NewsItem)getChild("NewsItem", index);
    }


    /**
     * @see NewsML#getNewsItem()
     */
    public NewsItem [] getNewsItem ()
    {
	int len = getNewsItemCount();
	NewsItem ret[] = new NewsItem[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getNewsItem(i);
	return ret;
    }

}

// end of DOMNewsML.java
