// DOMNewsManagement.java - DOM implementation of NewsManagement.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMNewsManagement.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.FormalName;
import org.newsml.toolkit.IdText;
import org.newsml.toolkit.Instruction;
import org.newsml.toolkit.NewsItemRef;
import org.newsml.toolkit.NewsManagement;
import org.newsml.toolkit.RevisionHistory;
import org.newsml.toolkit.StatusWillChange;


/**
 * DOM implementation of NewsManagement.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMNewsManagement
    extends DOMBaseNode
    implements NewsManagement
{


    /**
     * Constructor.
     *
     * @param element The DOM node representing the NewsManagement object.
     */
    protected DOMNewsManagement (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see NewsManagement#getNewsItemType()
     */
    public FormalName getNewsItemType ()
    {
	return (FormalName)getChild("NewsItemType", 0);
    }


    /**
     * @see NewsManagement#getFirstCreated()
     */
    public IdText getFirstCreated ()
    {
	return (IdText)getChild("FirstCreated", 0);
    }


    /**
     * @see NewsManagement#getThisRevisionCreated()
     */
    public IdText getThisRevisionCreated ()
    {
	return (IdText)getChild("ThisRevisionCreated", 0);
    }


    /**
     * @see NewsManagement#getStatus()
     */
    public FormalName getStatus ()
    {
	return (FormalName)getChild("Status", 0);
    }


    /**
     * @see NewsManagement#getStatusWillChange()
     */
    public StatusWillChange getStatusWillChange ()
    {
	return (StatusWillChange)getChild("StatusWillChange", 0);
    }


    /**
     * @see NewsManagement#getUrgency()
     */
    public FormalName getUrgency ()
    {
	return (FormalName)getChild("Urgency", 0);
    }


    /**
     * @see NewsManagement#getRevisionHistory()
     */
    public RevisionHistory getRevisionHistory ()
    {
	return (RevisionHistory)getChild("RevisionHistory", 0);
    }


    /**
     * @see NewsManagement#getDerivedFromCount()
     */
    public int getDerivedFromCount ()
    {
	return getChildCount("DerivedFrom");
    }


    /**
     * @see NewsManagement#getDerivedFrom(int)
     */
    public NewsItemRef getDerivedFrom (int index)
    {
	return (NewsItemRef)getChild("DerivedFrom", index);
    }


    /**
     * @see NewsManagement#getDerivedFrom()
     */
    public NewsItemRef [] getDerivedFrom ()
    {
	int len = getDerivedFromCount();
	NewsItemRef ret[] = new NewsItemRef[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getDerivedFrom(i);
	return ret;
    }


    /**
     * @see NewsManagement#getAssociatedWithCount()
     */
    public int getAssociatedWithCount ()
    {
	return getChildCount("AssociatedWith");
    }


    /**
     * @see NewsManagement#getAssociatedWith(int)
     */
    public NewsItemRef getAssociatedWith (int index)
    {
	return (NewsItemRef)getChild("AssociatedWith", index);
    }


    /**
     * @see NewsManagement#getAssociatedWith()
     */
    public NewsItemRef [] getAssociatedWith ()
    {
	int len = getAssociatedWithCount();
	NewsItemRef ret[] = new NewsItemRef[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getAssociatedWith(i);
	return ret;
    }


    /**
     * @see NewsManagement#getInstructionCount()
     */
    public int getInstructionCount ()
    {
	return getChildCount("Instruction");
    }


    /**
     * @see NewsManagement#getInstruction(int)
     */
    public Instruction getInstruction (int index)
    {
	return (Instruction)getChild("Instruction", index);
    }



    /**
     * @see NewsManagement#getInstruction()
     */
    public Instruction [] getInstruction ()
    {
	int len = getInstructionCount();
	Instruction ret[] = new Instruction[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getInstruction(i);
	return ret;
    }

}

// end of DOMNewsManagement.java
