// DOMOriginBase.java - DOM implementation of AssignedOriginText, Origin and OriginText.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMOriginBase.java,v 1.6 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import org.newsml.toolkit.AssignedOriginText;
import org.newsml.toolkit.Origin;
import org.newsml.toolkit.OriginNode;
import org.newsml.toolkit.OriginText;

import java.util.Vector;


/**
 * DOM implementation of AssignedOriginText, Origin, and OriginText.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMOriginBase
    extends DOMText
    implements AssignedOriginText, Origin, OriginText
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the origin text.
     */
    protected DOMOriginBase (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see OriginNode#getChunkCount()
     */
    public int getChunkCount ()
    {
	return getChunks(getDOMNode().getChildNodes(), new Vector()).size();
    }


    /**
     * @see OriginNode#getChunkType(int)
     */
    public int getChunkType (int index)
    {
	Node node = (Node)getChunks(getDOMNode().getChildNodes(), new Vector())
	    .elementAt(index);
	if (node.getNodeType() == Node.TEXT_NODE ||
	    node.getNodeType() == Node.CDATA_SECTION_NODE) {
	    return OriginNode.TEXT;
	} else {
	    return OriginNode.ORIGIN;
	}
    }


    /**
     * @see OriginNode#getData(index)
     */
    public String getData (int index)
    {
	Node node = (Node)getChunks(getDOMNode().getChildNodes(), new Vector())
	    .elementAt(index);
	if (node.getNodeType() == Node.TEXT_NODE ||
	    node.getNodeType() == Node.CDATA_SECTION_NODE) {
	    return node.getNodeValue();
	} else {
	    return null;
	}
    }


    /**
     * @see OriginNode#getOrigin(index)
     */
    public Origin getOrigin (int index)
    {
	Node node = (Node)getChunks(getDOMNode().getChildNodes(), new Vector())
	    .elementAt(index);
	if (node.getNodeType() == Node.TEXT_NODE ||
	    node.getNodeType() == Node.CDATA_SECTION_NODE) {
	    return null;
	} else {
	    return new DOMOriginBase(node, session);
	}
    }


    /**
     * Create an list of eligable DOM nodes.
     *
     * Walk the node list, recursing into entities and document
     * fragments, assembling a list of eligable nodes.
     * FIXME: this is very inefficient.
     *
     * @param nodes The node list to examine.
     * @param chunks The vector where nodes should be added.
     * @return The vector provided as an argument (for convenience).
     */
    private Vector getChunks (NodeList nodes, Vector chunks)
    {
	int max = nodes.getLength();
	for (int i = 0; i < max; i++) {
	    Node node = nodes.item(i);
	    switch (node.getNodeType()) {
	    case Node.ELEMENT_NODE:
	    case Node.TEXT_NODE:
	    case Node.CDATA_SECTION_NODE:
		chunks.addElement(node);
		break;
	    case Node.DOCUMENT_FRAGMENT_NODE:
	    case Node.ENTITY_NODE:
		getChunks(node.getChildNodes(), chunks);
		break;
	    }
	}
	return chunks;
    }

}

// end of DOMOriginBase.java
