// DOMResource.java - DOM implementation of Resource.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMResource.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.DefaultVocabularyFor;
import org.newsml.toolkit.IdText;
import org.newsml.toolkit.Resource;


/**
 * DOM implementation of Resource.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMResource
    extends DOMBaseNode
    implements Resource
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the basis for choice.
     */
    protected DOMResource (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see Property#getUrn()
     */
    public IdText getUrn ()
    {
	return (IdText)getChild("Urn", 0);
    }


    /**
     * @see Property#getUrlCount()
     */
    public int getUrlCount ()
    {
	return getChildCount("Url");
    }


    /**
     * @see Property#getUrl(int)
     */
    public IdText getUrl (int index)
    {
	return (IdText)getChild("Url", index);
    }


    /**
     * @see Resource#getUrl()
     */
    public IdText [] getUrl ()
    {
	int len = getUrlCount();
	IdText ret[] = new IdText[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getUrl(i);
	return ret;
    }


    /**
     * @see Property#getDefaultVocabularyForCount()
     */
    public int getDefaultVocabularyForCount ()
    {
	return getChildCount("DefaultVocabularyFor");
    }


    /**
     * @see Property#getDefaultVocabularyFor(int)
     */
    public DefaultVocabularyFor getDefaultVocabularyFor (int index)
    {
	return (DefaultVocabularyFor)getChild("DefaultVocabularyFor", index);
    }

    
    /**
     * @see Resource#getDefaultVocabularyFor()
     */
    public DefaultVocabularyFor [] getDefaultVocabularyFor ()
    {
	int len = getDefaultVocabularyForCount();
	DefaultVocabularyFor ret[] = new DefaultVocabularyFor[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getDefaultVocabularyFor(i);
	return ret;
    }

}

// end of DOMResource.java
