// DOMSubjectCode.java - DOM implementation of SubjectCode.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMSubjectCode.java,v 1.7 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import org.newsml.toolkit.AssignedFormalName;
import org.newsml.toolkit.SubjectCode;
import org.newsml.toolkit.SubjectCodeItem;


/**
 * DOM implementation of SubjectCode.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMSubjectCode
    extends DOMBaseNode
    implements SubjectCode
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the subject code.
     */
    protected DOMSubjectCode (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see SubjectCode#getSubjectCount()
     */
    public int getSubjectCount ()
    {
	return getChildCount("Subject");
    }


    /**
     * @see SubjectCode#getSubject(int)
     */
    public AssignedFormalName getSubject (int index)
    {
	return (AssignedFormalName)getChild("Subject", index);
    }


    /**
     * @see SubjectCode#getSubject()
     */
    public AssignedFormalName [] getSubject ()
    {
	int len = getSubjectCount();
	AssignedFormalName ret[] = new AssignedFormalName[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getSubject(i);
	return ret;
    }


    /**
     * @see SubjectCode#getSubjectMatterCount()
     */
    public int getSubjectMatterCount ()
    {
	return getChildCount("SubjectMatter");
    }


    /**
     * @see SubjectCode#getSubjectMatter(int)
     */
    public AssignedFormalName getSubjectMatter (int index)
    {
	return (AssignedFormalName)getChild("SubjectMatter", index);
    }


    /**
     * @see SubjectCode#getSubjectMatter()
     */
    public AssignedFormalName [] getSubjectMatter ()
    {
	int len = getSubjectMatterCount();
	AssignedFormalName ret[] = new AssignedFormalName[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getSubjectMatter(i);
	return ret;
    }


    /**
     * @see SubjectCode#getSubjectDetailCount()
     */
    public int getSubjectDetailCount ()
    {
	return getChildCount("SubjectDetail");
    }


    /**
     * @see SubjectCode#getSubjectDetail(int)
     */
    public AssignedFormalName getSubjectDetail (int index)
    {
	return (AssignedFormalName)getChild("SubjectDetail", index);
    }


    /**
     * @see SubjectCode#getSubjectDetail()
     */
    public AssignedFormalName [] getSubjectDetail ()
    {
	int len = getSubjectDetailCount();
	AssignedFormalName ret[] = new AssignedFormalName[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getSubjectDetail(i);
	return ret;
    }


    /**
     * @see SubjectCode#getSubjectQualifierCount()
     */
    public int getSubjectQualifierCount ()
    {
	return getChildCount("SubjectQualifier");
    }


    /**
     * @see SubjectCode#getSubjectQualifier(int)
     */
    public AssignedFormalName getSubjectQualifier (int index)
    {
	return (AssignedFormalName)getChild("SubjectQualifier", index);
    }


    /**
     * @see SubjectCode#getSubjectQualifier()
     */
    public AssignedFormalName [] getSubjectQualifier ()
    {
	int len = getSubjectQualifierCount();
	AssignedFormalName ret[] = new AssignedFormalName[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getSubjectQualifier(i);
	return ret;
    }


    /**
     * @see SubjectCode#getItemCount()
     */
    public int getItemCount ()
    {
	return (getChildCount("Subject") +
		getChildCount("SubjectMatter") +
		getChildCount("SubjectDetail"));
    }


    /**
     * @see SubjectCode#getItem(int)
     */
    public SubjectCodeItem getItem (int index)
    {
	Node node = getDOMNode();
	NodeList children = node.getChildNodes();

	for (int i = 0; i < children.getLength(); i++) {
	    Node child = children.item(i);
	    String name = child.getNodeName();
	    if ("Subject".equals(name) ||
		"SubjectMatter".equals(name) ||
		"SubjectDetail".equals(name)) {
		if (index == 0)
		    return new Item(node, i, session);
		else
		    index--;
	    }
	}
	return null;
    }
    

    /**
     * @see SubjectCode#getItem()
     */
    public SubjectCodeItem [] getItem ()
    {
	int len = getItemCount();
	SubjectCodeItem ret[] = new SubjectCodeItem[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getItem(i);
	return ret;
    }


    /**
     * Inner class implementing SubjectCodeItem.
     */
    class Item
	implements SubjectCodeItem
    {

	Item (Node parent, int pos, DOMNewsMLSession session)
	{
	    this.parent = parent;
	    this.pos = pos;
	    this.session = session;
	}


	/**
	 * @see SubjectCodeItem#getSubject()
	 */
	public AssignedFormalName getSubject ()
	{
	    return getItem("Subject");
	}


	/**
	 * @see SubjectCodeItem#getSubjectMatter()
	 */
	public AssignedFormalName getSubjectMatter ()
	{
	    return getItem("SubjectMatter");
	}


	/**
	 * @see SubjectCodeItem#getSubjectDetail()
	 */
	public AssignedFormalName getSubjectDetail ()
	{
	    return getItem("SubjectDetail");
	}


	/**
	 * @see SubjectCodeItem#getSubjectQualifierCount()
	 */
	public int getSubjectQualifierCount ()
	{
	    int count = 0;
	    NodeList children = parent.getChildNodes();
	    for (int i = pos + 1; i < children.getLength(); i++) {
		Node child = children.item(i);
		if (child.getNodeType() == Node.ELEMENT_NODE) {
		    if ("SubjectQualifier".equals(child.getNodeName()))
			count++;
		    else
			break;
		}
	    }
	    return count;
	}


	/**
	 * @see SubjectCodeItem#getSubjectQualifier(int)
	 */
	public AssignedFormalName getSubjectQualifier (int index)
	{
	    NodeList children = parent.getChildNodes();
	    for (int i = pos + 1; i < children.getLength(); i++) {
		Node child = children.item(i);
		if (child.getNodeType() == Node.ELEMENT_NODE) {
		    if ("SubjectQualifier".equals(child.getNodeName())) {
			if (index == 0)
			    return new DOMFormalName(child, session);
			else
			    index--;
		    } else {
			break;
		    }
		}
	    }
	    return null;
	}


	/**
	 * @see SubjectCodeItem#getSubjectQualifier()
	 */
	public AssignedFormalName [] getSubjectQualifier ()
	{
	    int len = getSubjectQualifierCount();
	    AssignedFormalName ret[] = new AssignedFormalName[len];
	    for (int i = 0; i < len; i++)
		ret[i] = getSubjectQualifier(i);
	    return ret;
	}


	/**
	 * Find an item by XML element name.
	 */
	private AssignedFormalName getItem (String name)
	{
	    Node child = parent.getChildNodes().item(pos);
	    if (child != null && name.equals(child.getNodeName()))
		return new DOMFormalName(child, session);
	    else
		return null;
	}

	private Node parent;
	private int pos;
	private DOMNewsMLSession session;
    }

}

// end of DOMSubjectCode.java
