// DOMText.java - DOM implementation of Comment, Description, and Text.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMText.java,v 1.8 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import java.io.IOException;

import org.w3c.dom.Node;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.BasisForChoice;
import org.newsml.toolkit.Comment;
import org.newsml.toolkit.Description;
import org.newsml.toolkit.IdText;
import org.newsml.toolkit.RevisionId;
import org.newsml.toolkit.Text;
import org.newsml.toolkit.TransmissionId;


/**
 * DOM implementation of Comment, Description, and Text
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMText
    extends DOMBaseNode
    implements BasisForChoice, Comment, Description, IdText,
	       RevisionId, TransmissionId
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the text.
     */
    protected DOMText (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }

    
    /**
     * @see Description#getVariant()
     */
    public Text getVariant ()
    {
	return getAttribute("Variant");
    }


    /**
     * @see BasisForChoice#getRank()
     */
    public Text getRank ()
    {
	return getAttribute("Rank");
    }


    /**
     * See Comment#getTranslationOf
     */
    public Text getTranslationOf ()
    {
	return getAttribute("TranslationOf");
    }


    /**
     * See Comment#getReferencedComment
     */
    public Comment getReferencedComment ()
	throws IOException
    {
	BaseNode node = null;
	Text ref = getTranslationOf();
	if (ref != null)
	    node = session.findReference(ref.toString(), false);

	if (node != null) {
	    if (!"Comment".equals(node.getXMLName()))
		throw new IOException("Comment reference points to " +
				      node.getXMLName());
	    else
		return (Comment)node;
	}

	return null;
    }


    /**
     * @see TransmissionId#getRepeat()
     */
    public Text getRepeat ()
    {
	return getAttribute("Repeat");
    }

    /**
     * @see RevisionId#getPreviousRevision()
     */
    public Text getPreviousRevision ()
    {
	return getAttribute("PreviousRevision");
    }


    /**
     * @see RevisionId#getUpdate()
     */
    public Text getUpdate ()
    {
	return getAttribute("Update");
    }


    /**
     * @see Text#toBoolean()
     */
    public boolean toBoolean ()
    {
	if (toString().equals("yes"))
	    return true;
	else
	    return false;
    }


    /**
     * @see Text#toInt()
     */
    public int toInt ()
    {
	try {
	    return Integer.parseInt(toString());
	} catch (NumberFormatException e) {
	    return -1;
	}
    }


    /**
     * @see Text#toString()
     */
    public String toString ()
    {
	return getDOMContent();
    }

}

// end of DOMText.java
