// DOMTopic.java - DOM implementation of Topic.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMTopic.java,v 1.7 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.Description;
import org.newsml.toolkit.FormalName;
import org.newsml.toolkit.FormalNameDecl;
import org.newsml.toolkit.Text;
import org.newsml.toolkit.Topic;


/**
 * DOM implementation of Topic.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMTopic
    extends DOMBaseNode
    implements Topic
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the topic.
     */
    protected DOMTopic (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see Topic#getDetails()
     */
    public Text getDetails ()
    {
	return getAttribute("Details");
    }


    /**
     * @see Topic#getTopicTypeCount()
     */
    public int getTopicTypeCount ()
    {
	return getChildCount("TopicType");
    }


    /**
     * @see Topic#getTopicType(int)
     */
    public FormalName getTopicType (int index)
    {
	return (FormalName)getChild("TopicType", index);
    }

    
    /**
     * @see Topic#getTopicType()
     */
    public FormalName [] getTopicType ()
    {
	int len = getTopicTypeCount();
	FormalName ret[] = new FormalName[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getTopicType(i);
	return ret;
    }


    /**
     * @see Topic#getFormalNameDeclCount()
     */
    public int getFormalNameDeclCount ()
    {
	return getChildCount("FormalName");
    }


    /**
     * @see Topic#getFormalNameDecl(int)
     */
    public FormalNameDecl getFormalNameDecl (int index)
    {
	return (FormalNameDecl)getChild("FormalName", index);
    }


    /**
     * @see Topic#getFormalNameDecl()
     */
    public FormalNameDecl [] getFormalNameDecl ()
    {
	int len = getFormalNameDeclCount();
	FormalNameDecl ret[] = new FormalNameDecl[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getFormalNameDecl(i);
	return ret;
    }


    /**
     * @see Topic#getDescriptionCount()
     */
    public int getDescriptionCount ()
    {
	return getChildCount("Description");
    }


    /**
     * @see Topic#getDescription(int)
     */
    public Description getDescription (int index)
    {
	return (Description)getChild("Description", index);
    }


    /**
     * @see Topic#getDescription()
     */
    public Description [] getDescription ()
    {
	int len = getDescriptionCount();
	Description ret[] = new Description[len];
	for (int i = 0; i < len; i++)
	    ret[i] = getDescription(i);
	return ret;
    }

}

// end of DOMTopic.java
