// DOMUpdate.java - DOM implementation of Update.
// Copyright (c) 2001 by Reuters PLC.
// $Id: DOMUpdate.java,v 1.2 2001/11/26 16:33:37 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.dom;

import org.w3c.dom.Node;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.Delta;
import org.newsml.toolkit.Update;


/**
 * DOM implementation of Update.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class DOMUpdate
    extends DOMBaseNode
    implements Update
{

    /**
     * Constructor.
     *
     * @param element The DOM node representing the update.
     */
    protected DOMUpdate (Node element, DOMNewsMLSession session)
    {
	super(element, session);
    }


    /**
     * @see Update#getDeltaCount()
     */
    public int getDeltaCount ()
    {
	return (getChildCount("InsertBefore")
		+ getChildCount("InsertAfter")
		+ getChildCount("Replace")
		+ getChildCount("Delete"));
    }


    /**
     * @see Update#getDelta(int)
     */
    public Delta getDelta (int index)
    {
	int nChildren = getChildCount();
	for (int i = 0; i < nChildren; i++) {
	    BaseNode child = getChild(i);
	    String name = child.getXMLName();
	    if ("InsertBefore".equals(name) ||
		"InsertAfter".equals(name) ||
		"Replace".equals(name) ||
		"Delete".equals(name)) {
		if (index == 0)
		    return (Delta)child;
		else
		    index--;
	    }
	}
	return null;
    }


    /**
     * @see Update#getDelta()
     */
    public Delta [] getDelta ()
    {
	int nDeltas = getDeltaCount();
	Delta deltas[] = new Delta[nDeltas];
	for (int i = 0; i < nDeltas; i++)
	    deltas[i] = getDelta(i);
	return deltas;
    }

}

// end of DOMUpdate.java
