// AdministrativeMetadataTest.java - unit tests for AdministrativeMetadata

package org.newsml.toolkit.dom.unittests;

import junit.framework.TestCase;

import org.newsml.toolkit.AdministrativeMetadata;

public class AdministrativeMetadataTest extends TestCase
{

    public AdministrativeMetadataTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getNewsItem(0)
	    .getRootNewsComponent().getAdministrativeMetadata();
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "AdministrativeMetadata");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid().toString(), "adm01");
	assertEquals(sample.getEuid().toString(), "id1");
    }

    public void testCatalog ()
    {
	assertNotNull(sample.getCatalog());
    }

    public void testFileName ()
    {
	assertEquals(sample.getFileName().toString(), "dog.xml");
    }

    public void testSystemIdentifier ()
    {
	assertEquals(sample.getSystemIdentifier().toString(),
		     "ftp://acmenews.com/stories/dog.xml");
    }

    public void testProviders ()
    {
	assertNotNull(sample.getProvider());
    }

    public void testCreators ()
    {
	assertNotNull(sample.getCreator());
    }

    public void testSource ()
    {
	assertEquals(sample.getSourceCount(), 2);
        assertEquals(sample.getSource().length, 2);
	assertNotNull(sample.getSource(0));
	assertNotNull(sample.getSource(1));
	assertNull(sample.getSource(2));
    }

    public void testContributor ()
    {
	assertEquals(sample.getContributorCount(), 2);
        assertEquals(sample.getContributor().length, 2);
	assertNotNull(sample.getContributor(0));
	assertNotNull(sample.getContributor(1));
	assertNull(sample.getContributor(2));
    }

    public void testProperty ()
    {
	assertEquals(sample.getPropertyCount(), 2);
        assertEquals(sample.getProperty().length, 2);
	assertNotNull(sample.getProperty(0));
	assertNotNull(sample.getProperty(1));
	assertNull(sample.getProperty(2));
    }

    private AdministrativeMetadata sample;

}

// end of AdministrativeMetadataTest.java
