// CatalogTest.java - unit tests for Catalog

package org.newsml.toolkit.dom.unittests;

import java.io.IOException;

import junit.framework.TestCase;

import org.newsml.toolkit.Catalog;

public class CatalogTest extends TestCase
{

    public CatalogTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getCatalog();
	sample2 = SampleFactory.createNewsML().getNewsItem(0).getCatalog();
	sample3 = SampleFactory.createNewsML().getTopicSet(1).getCatalog();
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "Catalog");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid().toString(), "catalog.a");
	assertEquals(sample.getEuid().toString(), "id1");
    }

    public void testHref ()
    {
	assertEquals(sample2.getHref().toString(), "#catalog.a");
    }

    public void testResource ()
    {
	assertEquals(sample.getResourceCount(), 2);
        assertEquals(sample.getResource().length, 2);
	assertEquals(sample2.getResourceCount(), 0);
	assertEquals(sample2.getResource().length, 0);
	assertEquals(sample3.getResourceCount(), 0);
	assertEquals(sample3.getResource().length, 0);
	assertNotNull(sample.getResource(0));
	assertNotNull(sample.getResource(1));
	assertNull(sample.getResource(2));
    }

    public void testTopicUse ()
    {
	assertEquals(sample.getTopicUseCount(), 2);
        assertEquals(sample.getTopicUse().length, 2);
	assertNotNull(sample.getTopicUse(0));
	assertNotNull(sample.getTopicUse(1));
	assertNull(sample.getTopicUse(2));
    }

    public void testInternalReferencedCatalog ()
	throws IOException
    {
	assertEquals(sample, sample2.getReferencedCatalog(false));
	assertEquals(sample2.getReferencedCatalog(false).getResourceCount(), 2);
    }

    public void testExternalReferencedCatalog ()
	throws IOException
    {
	Catalog catalog = sample3.getReferencedCatalog(true);
	assertNotNull(catalog);
    }

    private Catalog sample;
    private Catalog sample2;
    private Catalog sample3;
    
}

// end of CatalogTest.java
