// ContentItemTest.java - unit tests for org.newsml.toolkit.dom.ContentItem

package org.newsml.toolkit.dom.unittests;

import java.io.IOException;

import junit.framework.TestCase;

import org.xml.sax.SAXException;

import org.newsml.toolkit.ContentItem;
import org.newsml.toolkit.NewsComponent;


public class ContentItemTest extends TestCase
{

    public ContentItemTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = (ContentItem)(SampleFactory.createNewsML()
			       .getChild("NewsItem", 0)
			       .getChild("NewsComponent", 0)
			       .getChild("NewsComponent", 1)
			       .getChild("ContentItem", 0));
	sample2 = (ContentItem)(sample.getParent().getChild("ContentItem", 1));
	sample3 = (ContentItem)(sample.getParent().getChild("ContentItem", 2));
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "ContentItem");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid().toString(), "con01");
	assertEquals(sample.getEuid().toString(), "id1");
    }

    public void testHref ()
    {
	assertEquals(sample.getHref().toString(),
		     "http://www.acmenews.com/story1.xml");
    }

    public void testComment ()
    {
	assertEquals(sample.getCommentCount(), 2);
        assertEquals(sample.getComment().length, 2);
	assertNotNull(sample.getComment(0));
	assertNotNull(sample.getComment(1));
	assertNull(sample.getComment(2));
    }

    public void testCatalog ()
    {
	assertNotNull(sample.getCatalog());
    }

    public void testMediaType ()
    {
	assertEquals(sample.getMediaType().getName().toString(), "text");
    }

    public void testFormat ()
    {
	assertEquals(sample.getFormat().getName().toString(), "nitf");
    }

    public void testMimeType ()
    {
	assertEquals(sample.getMimeType().getName().toString(), "text/x-nitf");
    }

    public void testNotation ()
    {
	assertEquals(sample.getNotation().getName().toString(), "nitf-xml");
    }

    public void testCharacteristics ()
    {
	assertNotNull(sample.getCharacteristics());
    }

    public void testEncoding ()
    {
	assertNull(sample.getEncoding());
	assertNotNull(sample2.getEncoding());
	assertNull(sample3.getEncoding());
    }

    public void testDataContent ()
    {
	assertNull(sample.getDataContent());
	assertNull(sample2.getDataContent());
	assertNotNull(sample3.getDataContent());
    }

    private ContentItem sample;
    private ContentItem sample2;
    private ContentItem sample3;

}

// end of ContentItemTest.java
