// DescriptiveMetadataTest.java - unit tests for DescriptiveMetadata

package org.newsml.toolkit.dom.unittests;

import junit.framework.TestCase;

import org.newsml.toolkit.AssignedText;
import org.newsml.toolkit.DescriptiveMetadata;
import org.newsml.toolkit.TopicOccurrence;

public class DescriptiveMetadataTest extends TestCase
{

    public DescriptiveMetadataTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getNewsItem(0)
	    .getRootNewsComponent().getDescriptiveMetadata();
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "DescriptiveMetadata");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid().toString(), "des01");
	assertEquals(sample.getEuid().toString(), "id1");
    }

    public void testAssignment ()
    {
	assertEquals(sample.getAssignedBy().toString(), "assigned-by-2");
	assertEquals(sample.getConfidence().getName().toString(), "confidence-2");
	assertEquals(sample.getAssignmentDateAndTime().toString(),
		     "2000-12-30");
	assertEquals(sample.getHowPresent().getName().toString(), "how-present-2");
	assertEquals(sample.getImportance().getName().toString(), "importance-2");
    }

    public void testCatalog ()
    {
	assertNotNull(sample.getCatalog());
    }

    public void testLanguage ()
    {
	assertEquals(sample.getLanguageCount(), 2);
        assertEquals(sample.getLanguage().length, 2);
	assertEquals(sample.getLanguage(0).getName().toString(), "en-US");
	assertEquals(sample.getLanguage(1).getName().toString(), "en-UK");
	assertNull(sample.getLanguage(2));
    }

    public void testGenre ()
    {
	assertEquals(sample.getGenre().getName().toString(), "genre.a");
    }

    public void testSubjectCode ()
    {
	assertEquals(sample.getSubjectCodeCount(), 2);
        assertEquals(sample.getSubjectCode().length, 2);
	assertNotNull(sample.getSubjectCode(0));
	assertNotNull(sample.getSubjectCode(1));
	assertNull(sample.getSubjectCode(2));
    }

    public void testOfInterestTo ()
    {
	assertEquals(sample.getOfInterestToCount(), 2);
        assertEquals(sample.getOfInterestTo().length, 2);
	assertEquals(sample.getOfInterestTo(0).getName().toString(), "interest.a");
	assertEquals(sample.getOfInterestTo(1).getName().toString(), "interest.b");
	assertEquals(sample.getOfInterestTo(1).getRelevance().getName().toString(),
		     "relevance");
	assertNull(sample.getOfInterestTo(2));
    }

    public void testTopicOccurrence ()
    {
	assertEquals(sample.getTopicOccurrenceCount(), 2);
        assertEquals(sample.getTopicOccurrence().length, 2);
	assertEquals(sample.getTopicOccurrence(0).getTopicRef().toString(),
		     "topic.a");
	assertEquals(sample.getTopicOccurrence(1).getTopicRef().toString(),
		     "topic.b");
	assertNull(sample.getTopicOccurrence(2));
	TopicOccurrence t = sample.getTopicOccurrence(0);
	assertEquals(t.getAssignedBy().toString(), "assigned-by-888");
	assertEquals(t.getImportance().getName().toString(), "importance-888");
	assertEquals(t.getConfidence().getName().toString(), "confidence-888");
	assertEquals(t.getHowPresent().getName().toString(), "how-present-888");
	assertEquals(t.getAssignmentDateAndTime().toString(), "1900-01-01");
	assertEquals(t.getAssignedBy().toString(), "assigned-by-888");
    }

    public void testProperty ()
    {
	assertEquals(sample.getPropertyCount(), 2);
        assertEquals(sample.getProperty().length, 2);
	assertNotNull(sample.getProperty(0));
	assertNotNull(sample.getProperty(1));
	assertNull(sample.getProperty(2));
    }

    private DescriptiveMetadata sample;

}

// end of DescriptiveMetadataTest.java
