// FormalNameTest.java - unit tests for FormalName

package org.newsml.toolkit.dom.unittests;

import java.io.IOException;

import junit.framework.TestCase;

import org.newsml.toolkit.FormalName;
import org.newsml.toolkit.Topic;

public class FormalNameTest extends TestCase
{

    public FormalNameTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getNewsItem(0)
	    .getNewsManagement().getNewsItemType();
	sample2 = SampleFactory.createNewsML().getTopicSet(1).getTopic(0)
	    .getTopicType(0);
	sample3 = (FormalName)(SampleFactory.createNewsML()
			       .getChild("NewsItem", 0)
			       .getChild("Identification", 0)
			       .getChild("NewsIdentifier", 0)
			       .getChild("NewsItemId", 0));
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "NewsItemType");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid().toString(), "newsitemtype01");
	assertEquals(sample.getEuid().toString(), "id1");
	assertEquals(sample2.getDuid().toString(), "topictype-x");
    }

    public void testName ()
    {
	assertEquals(sample.getName().toString(), "sample");
    }

    public void testVocabulary ()
    {
	assertEquals(sample.getVocabulary().toString(), "#vocab.newsitemtype");
	assertNull(sample2.getVocabulary());
	assertEquals(sample3.getVocabulary().toString(), "vocabularyxx");
    }

    public void testInternalDefaultVocabulary ()
	throws IOException
    {
	assertEquals(sample.getDefaultVocabulary(false), "#vocab.newsitemtype");
	assertEquals(sample2.getDefaultVocabulary(false), "#vocab.topictype");
    }

    public void testExternalDefaultVocabulary ()
	throws IOException
    {
	assertEquals(sample.getDefaultVocabulary(true), "#vocab.newsitemtype");
	assertEquals(sample2.getDefaultVocabulary(true),
		     "http://www.foo.com/topicset.xml");
    }

    public void testScheme ()
    {
	assertEquals(sample.getScheme().toString(), "scheme.a");
	assertEquals(sample3.getScheme().toString(), "schemexx");
    }

    public void testInternalDefaultScheme ()
	throws IOException
    {
	assertEquals(sample2.getDefaultScheme(false), "Scheme");
    }

    public void testTopicSet ()
	throws IOException
    {
	assertNotNull(sample.getTopicSet(false));
	assertEquals(sample.getTopicSet(false).getName().toString(), "topicset.e");
    }

    public void testDefaultTopicSet ()
	throws IOException
    {
	assertNotNull(sample2.getTopicSet(false));
	assertEquals(sample2.getTopicSet(false).getName().toString(), "topicset.d");
    }

    public void testTopic ()
	throws IOException
    {
	Topic topic = sample.findTopic(false);
	assertNotNull(topic);
    }

    public void testToString ()
	throws IOException
    {
	assertEquals(sample.toString(), 
		     "{#vocab.newsitemtype}{scheme.a}sample");
	assertEquals(sample2.toString(), "{}{}topic.a");
	assertEquals(sample2.toString(false), "{#vocab.topictype}{Scheme}topic.a");
	assertEquals(sample2.toString(true),
		     "{http://www.foo.com/topicset.xml}{}topic.a");
    }

    protected FormalName sample;
    protected FormalName sample2;
    protected FormalName sample3;

}

// end of FormalNameTest.java
