// NewsComponentTest.java - unit tests for org.newsml.toolkit.dom.NewsComponent

package org.newsml.toolkit.dom.unittests;

import java.io.IOException;

import junit.framework.TestCase;

import org.xml.sax.SAXException;

import org.newsml.toolkit.NewsComponent;


public class NewsComponentTest extends TestCase
{

    public NewsComponentTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getNewsItem(0)
	    .getRootNewsComponent();
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "NewsComponent");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid().toString(), "newscomponent01");
	assertEquals(sample.getEuid().toString(), "id1");
    }

    public void testEssential ()
    {
	assert(!sample.getEssential().toBoolean());
    }

    public void testEquivalents ()
    {
	assert(sample.getEquivalentsList().toBoolean());
    }

    public void testLanguage ()
    {
	assertEquals(sample.getLang().toString(), "en");
    }

    public void testComment ()
    {
	assertEquals(sample.getCommentCount(), 2);
        assertEquals(sample.getComment().length, 2);
	assertNotNull(sample.getComment(0));
	assertNotNull(sample.getComment(1));
	assertNull(sample.getComment(2));
    }

    public void testCatalog ()
    {
	assertNotNull(sample.getCatalog());
    }

    public void testTopicSet ()
    {
	assertEquals(sample.getTopicSetCount(), 2);
        assertEquals(sample.getTopicSet().length, 2);
	assertNotNull(sample.getTopicSet(0));
	assertNotNull(sample.getTopicSet(1));
	assertNull(sample.getTopicSet(2));
    }

    public void testRole ()
    {
	assertNotNull(sample.getRole());
	assertEquals(sample.getRole().getName().toString(), "story");
    }

    public void testBasisForChoice ()
    {
	assertEquals(sample.getBasisForChoiceCount(), 3);
	assertEquals(sample.getBasisForChoice().length, 3);
	assertNotNull(sample.getBasisForChoice(0));
	assertNotNull(sample.getBasisForChoice(1));
	assertNotNull(sample.getBasisForChoice(2));
	assertNull(sample.getBasisForChoice(3));
	assertEquals(sample.getRankedBasisForChoice()[0].toString(),
		     "MimeType");
    }

    public void testNewsLines ()
    {
	assertNotNull(sample.getNewsLines());
    }

    public void testAdministrativeMetadata ()
    {
	assertNotNull(sample.getAdministrativeMetadata());
    }

    public void testRightsMetadata ()
    {
	assertNotNull(sample.getRightsMetadata());
    }

    public void testDescriptiveMetadata ()
    {
	assertNotNull(sample.getDescriptiveMetadata());
    }

    public void testMetadata ()
    {
	assertEquals(sample.getMetadataCount(), 1);
	assertEquals(sample.getMetadata().length, 1);
	assertNotNull(sample.getMetadata(0));
	assertNull(sample.getMetadata(1));
    }

    public void testMember ()
    {
	assertEquals(sample.getMemberCount(), 2);
        assertEquals(sample.getMember().length, 2);
	assertNotNull(sample.getMember(0));
	assertNotNull(sample.getMember(1));
	assertNull(sample.getMember(2));
    }

    private NewsComponent sample;

}

// end of NewsComponentTest.java
