// NewsItemRefTest.java - unit tests for org.newsml.toolkit.dom.NewsItemRef

package org.newsml.toolkit.dom.unittests;

import java.io.IOException;

import junit.framework.TestCase;

import org.xml.sax.SAXException;

import org.newsml.toolkit.NewsItemRef;


public class NewsItemRefTest extends TestCase
{

    public NewsItemRefTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = (NewsItemRef)(SampleFactory.createNewsML()
			       .getChild("NewsItem", 0)
			       .getChild("NewsComponent", 0)
			       .getChild("NewsComponent", 0)
			       .getChild("NewsItemRef", 0));
	sample2 = (NewsItemRef)(sample.getParent()
				.getChild("NewsItemRef", 1));
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "NewsItemRef");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid().toString(), "newsitemref01");
	assertEquals(sample.getEuid().toString(), "id1");
    }

    public void testRef ()
    {
	assertEquals(sample.getRef().toString(), "#newsitem-x");
    }

    public void testInternalReference ()
	throws IOException
    {
	assertNotNull(sample.getReferencedNewsItem(false));
    }

    public void testExternalReference ()
	throws IOException
    {
	assertNull(sample2.getReferencedNewsItem(false));
	assertNotNull(sample2.getReferencedNewsItem(true));
    }

    public void testComment ()
    {
	assertEquals(sample.getCommentCount(), 2);
        assertEquals(sample.getComment().length, 2);
	assertNotNull(sample.getComment(0));
	assertNotNull(sample.getComment(1));
	assertNull(sample.getComment(2));
    }

    private NewsItemRef sample;
    private NewsItemRef sample2;

}

// end of NewsItemRefTest.java
