// NewsLinesTest.java - unit tests for NewsLines

package org.newsml.toolkit.dom.unittests;

import junit.framework.TestCase;

import org.newsml.toolkit.NewsLines;

public class NewsLinesTest extends TestCase
{

    public NewsLinesTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getNewsItem(0)
	    .getRootNewsComponent().getNewsLines();
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "NewsLines");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid().toString(), "newslines01");
	assertEquals(sample.getEuid().toString(), "id1");
    }

    public void testHeadLineGroup ()
    {
	assertEquals(sample.getHeadLineGroupCount(), 2);
        assertEquals(sample.getHeadLineGroup().length, 2);
	assertEquals(sample.getHeadLineGroup(0).getHeadLine().toString(),
		     "Dog bites man");
	assertNull(sample.getHeadLineGroup(0).getSubHeadLine());
	assertEquals(sample.getHeadLineGroup(1).getHeadLine().toString(),
		     "Man bites dog");
	assertEquals(sample.getHeadLineGroup(1).getSubHeadLine().toString(),
		     "Dog recovering");
	assertNull(sample.getHeadLineGroup(2));
    }

    public void testHeadLine ()
    {
	assertEquals(sample.getHeadLineCount(), 2);
        assertEquals(sample.getHeadLine().length, 2);
	assertEquals(sample.getHeadLine(1).toString(), "Man bites dog");
	assertNull(sample.getHeadLine(2));
    }

    public void testSubHeadLine ()
    {
	assertEquals(sample.getSubHeadLineCount(), 1);
        assertEquals(sample.getSubHeadLine().length, 1);
	assertEquals(sample.getSubHeadLine(0).toString(), "Dog recovering");
	assertNull(sample.getSubHeadLine(1));
    }

    public void testByLine ()
    {
	assertEquals(sample.getByLineCount(), 2);
        assertEquals(sample.getByLine().length, 2);
	assertEquals(sample.getByLine(1).toString(), "byline.b");
	assertNull(sample.getByLine(2));
    }

    public void testDateLine ()
    {
	assertEquals(sample.getDateLineCount(), 2);
        assertEquals(sample.getDateLine().length, 2);
	assertEquals(sample.getDateLine(0).toString(), "dateline.a");
	assertEquals(sample.getDateLine(1).toString(), "dateline.b");
	assertNull(sample.getDateLine(2));
    }

    public void testCreditLine ()
    {
	assertEquals(sample.getCreditLineCount(), 2);
        assertEquals(sample.getCreditLine().length, 2);
	assertEquals(sample.getCreditLine(0).toString(), "creditline.a");
	assertEquals(sample.getCreditLine(1).toString(), "creditline.b");
	assertNull(sample.getCreditLine(2));
    }

    public void testCopyrightLine ()
    {
	assertEquals(sample.getCopyrightLineCount(), 2);
        assertEquals(sample.getCopyrightLine().length, 2);
	assertEquals(sample.getCopyrightLine(0).toString(), "copyrightline.a");
	assertEquals(sample.getCopyrightLine(1).toString(), "copyrightline.b");
	assertNull(sample.getCopyrightLine(2));
    }

    public void testRightsLine ()
    {
	assertEquals(sample.getRightsLineCount(), 2);
        assertEquals(sample.getRightsLine().length, 2);
	assertEquals(sample.getRightsLine(0).toString(), "rightsline.a");
	assertEquals(sample.getRightsLine(1).toString(), "rightsline.b");
	assertNull(sample.getRightsLine(2));
    }

    public void testSeriesLine ()
    {
	assertEquals(sample.getSeriesLineCount(), 2);
        assertEquals(sample.getSeriesLine().length, 2);
	assertEquals(sample.getSeriesLine(0).toString(), "seriesline.a");
	assertEquals(sample.getSeriesLine(1).toString(), "seriesline.b");
	assertNull(sample.getSeriesLine(2));
    }

    public void testSlugLine ()
    {
	assertEquals(sample.getSlugLineCount(), 2);
        assertEquals(sample.getSlugLine().length, 2);
	assertEquals(sample.getSlugLine(0).toString(), "slugline.a");
	assertEquals(sample.getSlugLine(1).toString(), "slugline.b");
	assertNull(sample.getSlugLine(2));
    }

    public void testKeywordLine ()
    {
	assertEquals(sample.getKeywordLineCount(), 2);
        assertEquals(sample.getKeywordLine().length, 2);
	assertEquals(sample.getKeywordLine(0).toString(), "keywordline.a");
	assertEquals(sample.getKeywordLine(1).toString(), "keywordline.b");
	assertNull(sample.getKeywordLine(2));
    }

    public void testNewsLine ()
    {
	assertEquals(sample.getNewsLineCount(), 2);
        assertEquals(sample.getNewsLine().length, 2);
	assertNotNull(sample.getNewsLine(0));
	assertNotNull(sample.getNewsLine(1));
	assertNull(sample.getNewsLine(2));
    }

    private NewsLines sample;

}

// end of NewsLinesTest.java
