// NewsMLFactoryTest.java - unit tests for NewsMLFactory

package org.newsml.toolkit.dom.unittests;

import java.io.InputStreamReader;
import java.io.IOException;
import java.io.Reader;
import java.net.URL;

import junit.framework.TestCase;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.NewsML;
import org.newsml.toolkit.NewsMLException;
import org.newsml.toolkit.NewsMLFactory;

import org.newsml.toolkit.dom.DOMNewsMLFactory;
import org.newsml.toolkit.dom.XercesDOMFactory;

public class NewsMLFactoryTest extends TestCase
{

    public NewsMLFactoryTest (String name)
    {
	super(name);
    }

    protected void setUp ()
    {
	factory = new DOMNewsMLFactory(new XercesDOMFactory());
    }

    public void testNewsMLURL ()
	throws IOException
    {
	NewsML newsml = factory.createNewsML(makeURL("sample.xml"));
	assertNotNull(newsml);
	assertEquals(newsml.getXMLName(), "NewsML");

	boolean sawException = false;
	try {
	    factory.createNewsML(makeReader("sample-newsitem.xml"),
				 makeURL("sample-newsitem.xml"));
	} catch (NewsMLException e) {
	    sawException = true;
	}
	assert("NewsItem root element throws exception", sawException);


	sawException = false;
	try {
	    factory.createNewsML(makeReader("sample-nonconformant.xml"),
				 makeURL("sample-nonconformant.xml"));
	} catch (NewsMLException e) {
	    sawException = true;
	}
	assert("Bad root element throws exception", sawException);
    }

    public void testNewsMLStream ()
	throws IOException
    {
	NewsML newsml = factory.createNewsML(makeReader("sample.xml"),
					     makeURL("sample.xml"));
	assertNotNull(newsml);
	assertEquals(newsml.getXMLName(), "NewsML");

	boolean sawException = false;
	try {
	    factory.createNewsML(makeReader("sample-newsitem.xml"),
				 makeURL("sample-newsitem.xml"));
	} catch (NewsMLException e) {
	    sawException = true;
	}
	assert("NewsItem root element throws exception", sawException);


	sawException = false;
	try {
	    factory.createNewsML(makeReader("sample-nonconformant.xml"),
				 makeURL("sample-nonconformant.xml"));
	} catch (NewsMLException e) {
	    sawException = true;
	}
	assert("Bad root element throws exception", sawException);
    }

    public void testNodeURL ()
	throws IOException
    {
	BaseNode node = factory.createNode(makeURL("sample-newsitem.xml"));
	assertNotNull(node);
	assertEquals(node.getXMLName(), "NewsItem");
   }

    public void testNodeStream ()
	throws IOException
    {
	BaseNode node = factory.createNode(makeReader("sample-newsitem.xml"),
					   makeURL("sample-newsitem.xml"));
	assertNotNull(node);
	assertEquals(node.getXMLName(), "NewsItem");
    }

    public void testValidation ()
	throws IOException
    {
	boolean sawException = false;
	NewsMLFactory factory2 = new DOMNewsMLFactory(new XercesDOMFactory());

	factory2.setValidation(true);
	try {
	    factory2.createNewsML(makeURL("sample-invalid.xml"));
	} catch (IOException e) {
	    sawException = true;
	}
	assert("Invalid document throws exception", sawException);

	assertNotNull(factory2.createNewsML(makeURL("sample.xml")));
    }

    public void testNoValidation ()
	throws IOException
    {
	NewsMLFactory factory2 = new DOMNewsMLFactory(new XercesDOMFactory());
	
	factory2.setValidation(false);
	
	assertNotNull(factory2.createNewsML(makeURL("sample-invalid.xml")));
    }

    private String makeURL (String baseName)
    {
	URL url = NewsMLFactoryTest.class.getResource(baseName);
	return url.toString();
    }

    private Reader makeReader (String baseName)
	throws IOException
    {
	return new InputStreamReader(NewsMLFactoryTest.class
				     .getResourceAsStream(baseName));
    }

    private NewsMLFactory factory;

}

// end of NewsMLFactoryTest.java
