// NewsMLSessionTest.java - unit tests for NewsMLSession

package org.newsml.toolkit.dom.unittests;

import java.io.BufferedInputStream;
import java.io.InputStream;
import java.io.IOException;

import junit.framework.TestCase;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.NewsMLException;
import org.newsml.toolkit.NewsMLSession;

public class NewsMLSessionTest extends TestCase
{

    public NewsMLSessionTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getNewsItem(0).getSession();
    }

    public void testRootNode ()
    {
	assertEquals(sample.getRootNode().getXMLName(), "NewsML");
    }

    public void testInternalReference ()
	throws IOException
    {
	BaseNode target = sample.findReference("#topic01", false);
	assertNotNull(target);
	assertEquals(target.getXMLName(), "Topic");
    }

    public void testExternalReference ()
	throws IOException
    {
	BaseNode target = sample.findReference("sample-newsitem.xml#id01",
					       true);
	assertNotNull(target);
	assertEquals(target.getXMLName(), "Catalog");
    }

    public void testDuid ()
    {
	BaseNode target = sample.getNodeByDuid("topic01");
	assertNotNull(target);
	assertEquals(target.getXMLName(), "Topic");
    }

    public void testXPath ()
	throws NewsMLException
    {
				// Find the first TopicSet
	BaseNode node = sample.getNodeByXPath(sample.getRootNode(),
					      "descendant::TopicSet");
	assertEquals(node.getXMLName(), "TopicSet");

				// There should be three NewsComponents
	BaseNode nodes[] = sample.getNodesByXPath(sample.getRootNode(),
						  "descendant::NewsComponent");
	assertEquals(nodes.length, 3);
	for (int i = 0; i < 3; i++)
	    assertEquals(nodes[i].getXMLName(), "NewsComponent");

				// Test that a badly-formed path
				// throws a NewsMLException and nothing
				// else.
	boolean ok = false;
	try {
	    sample.getNodesByXPath(sample.getRootNode(), "daughter::foo");
	} catch (NewsMLException e) {
	    ok = true;
	}
	assert("Bad XPath threw a NewsMLException", ok);
    }

    public void testBaseURL ()
    {
	assertNotNull(sample.getBaseURL());
    }

    public void testResolveHref ()
	throws IOException
    {
	InputStream input =
	    sample.resolveHref("sample-invalid.xml").openStream();
	input = new BufferedInputStream(input);
	int size = 0;
	while (input.read() != -1)
	    size++;
	input.close();
	assert("href resource was not empty", size > 0);
    }

    private NewsMLSession sample;

}

// end of NewsMLSessionTest.java
