// NewsMLTest.java - unit tests for org.newsml.toolkit.dom.NewsML

package org.newsml.toolkit.dom.unittests;

import java.io.IOException;

import junit.framework.TestCase;

import org.xml.sax.SAXException;

import org.newsml.toolkit.NewsML;


public class NewsMLTest extends TestCase
{

    /**
     * Construct a NewsML Test with the specified name.
     *
     * @param name Test case name.
     */
    public NewsMLTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML();
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "NewsML");
	assertNotNull(sample.getSession());
	assertEquals(sample.getSession().getRootNode(), sample);
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid().toString(), "newsml01");
	assertEquals(sample.getEuid().toString(), "id1");
    }

    public void testCatalog ()
    {
	assertNotNull(sample.getCatalog());
    }

    public void testTopicSet ()
    {
	assertEquals(sample.getTopicSetCount(), 2);
        assertEquals(sample.getTopicSet().length, 2);
	assertNotNull(sample.getTopicSet(0));
	assertNotNull(sample.getTopicSet(1));
	assertNull(sample.getTopicSet(2));
    }

    public void testNewsEnvelope ()
    {
	assertNotNull(sample.getNewsEnvelope());
    }

    public void testNewsItem ()
    {
	assertEquals(sample.getNewsItemCount(), 3);
        assertEquals(sample.getNewsItem().length, 3);
	assertNotNull(sample.getNewsItem(0));
	assertNotNull(sample.getNewsItem(1));
	assertNotNull(sample.getNewsItem(2));
	assertNull(sample.getNewsItem(3));
    }

    public void testNoParent ()
    {
	assertNull(sample.getParent());
    }

    private NewsML sample;

}

// end of NewsMLTest.java
