// PropertyTest.java - unit tests for Property

package org.newsml.toolkit.dom.unittests;

import junit.framework.TestCase;

import org.newsml.toolkit.Property;

public class PropertyTest extends TestCase
{

    public PropertyTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getNewsItem(0)
	    .getNewsManagement().getProperty(1);
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "Property");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid().toString(), "property01");
	assertEquals(sample.getEuid().toString(), "id1");
    }

    public void testAssignment ()
    {
	assertEquals(sample.getAssignedBy().toString(), "assigned-by-3");
	assertEquals(sample.getConfidence().getName().toString(), "confidence-3");
	assertEquals(sample.getAssignmentDateAndTime().toString(),
		     "2000-12-29");
	assertEquals(sample.getHowPresent().getName().toString(), "how-present-3");
	assertEquals(sample.getImportance().getName().toString(), "importance-3");
    }

    public void testName ()
    {
	assertEquals(sample.getName().toString(), "property.b");
    }

    public void testValue ()
    {
	assertEquals(sample.getValue().toString(), "value.a");
    }

    public void testValueRef ()
    {
	assertEquals(sample.getValueRef().toString(), "valueref.a");
    }

    public void testAllowedValues ()
    {
	assertEquals(sample.getAllowedValues().toString(), "a b c");
    }

    public void testProperty ()
    {
	assertEquals(sample.getPropertyCount(), 2);
        assertEquals(sample.getProperty().length, 2);
	assertNotNull(sample.getProperty(0));
	assertNotNull(sample.getProperty(1));
	assertNull(sample.getProperty(2));
    }

    private Property sample;

}

// end of PropertyTest.java
