// ResourceTest.java - unit tests for Resource

package org.newsml.toolkit.dom.unittests;

import junit.framework.TestCase;

import org.newsml.toolkit.Resource;

public class ResourceTest extends TestCase
{

    public ResourceTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getCatalog().getResource(1);
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "Resource");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid().toString(), "resource01");
	assertEquals(sample.getEuid().toString(), "id1");
    }

    public void testUrn ()
    {
	assertEquals(sample.getUrn().toString(), "urn:xxx:yyy");
    }

    public void testUrl ()
    {
	assertEquals(sample.getUrlCount(), 2);
        assertEquals(sample.getUrl().length, 2);
	assertEquals(sample.getUrl(0).toString(), "#vocab.topictype");
	assertEquals(sample.getUrl(1).toString(), "http://www.host.net/url-b");
	assertNull(sample.getUrl(2));
    }

    public void testDefaultVocabularyFor ()
    {
	assertEquals(sample.getDefaultVocabularyForCount(), 2);
        assertEquals(sample.getDefaultVocabularyFor().length, 2);
	assertEquals(sample.getDefaultVocabularyFor(0).getContext().toString(),
		     "//node()/@HowPresent");
// 	assertEquals(sample.getDefaultVocabularyFor(1).getContext().toString(),
// 		     "Topic/TopicType");
	assertEquals(sample.getDefaultVocabularyFor(1).getScheme().toString(),
		     "Scheme");
	assertNull(sample.getDefaultVocabularyFor(2));
    }

    private Resource sample;

}

// end of ResourceTest.java
