// RightsMetadataTest.java - unit tests for RightsMetadata

package org.newsml.toolkit.dom.unittests;

import junit.framework.TestCase;

import org.newsml.toolkit.RightsMetadata;

public class RightsMetadataTest extends TestCase
{

    public RightsMetadataTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getNewsItem(0)
	    .getRootNewsComponent().getRightsMetadata();
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "RightsMetadata");
	assertNotNull(sample.getSession());
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid().toString(), "rightsmetadata01");
	assertEquals(sample.getEuid().toString(), "id1");
    }

    public void testAssignment ()
    {
	assertEquals(sample.getAssignedBy().toString(), "assigned-by-4");
	assertEquals(sample.getConfidence().getName().toString(), "confidence-4");
	assertEquals(sample.getAssignmentDateAndTime().toString(),
		     "2000-12-28");
	assertEquals(sample.getHowPresent().getName().toString(), "how-present-4");
	assertEquals(sample.getImportance().getName().toString(), "importance-4");
    }

    public void testCatalog ()
    {
	assertNotNull(sample.getCatalog());
    }

    public void testCopyright ()
    {
	assertEquals(sample.getCopyrightCount(), 2);
        assertEquals(sample.getCopyright().length, 2);
	assertNotNull(sample.getCopyright(0));
	assertNotNull(sample.getCopyright(1));
	assertNull(sample.getCopyright(2));
    }

    public void testUsageRights ()
    {
	assertEquals(sample.getUsageRightsCount(), 2);
        assertEquals(sample.getUsageRights().length, 2);
	assertNotNull(sample.getUsageRights(0));
	assertNotNull(sample.getUsageRights(1));
	assertNull(sample.getUsageRights(2));
    }

    public void testProperty ()
    {
	assertEquals(sample.getPropertyCount(), 2);
        assertEquals(sample.getProperty().length, 2);
	assertNotNull(sample.getProperty(0));
	assertNotNull(sample.getProperty(1));
	assertNull(sample.getProperty(2));
    }

    private RightsMetadata sample;

}

// end of RightsMetadataTest.java
