// SubjectCodeTest.java - unit tests for SubjectCode

package org.newsml.toolkit.dom.unittests;

import junit.framework.TestCase;

import org.newsml.toolkit.SubjectCode;

public class SubjectCodeTest extends TestCase
{

    public SubjectCodeTest (String name)
    {
	super(name);
    }

    protected void setUp ()
	throws Exception
    {
	super.setUp();
	sample = SampleFactory.createNewsML().getNewsItem(0)
	    .getRootNewsComponent().getDescriptiveMetadata().getSubjectCode(1);
    }

    public void testBase ()
    {
	assertEquals(sample.getXMLName(), "SubjectCode");
	assertNotNull(sample.getSession());
    }

    public void testSubject ()
    {
	assertEquals(sample.getSubjectCount(), 2);
	assertEquals(sample.getSubject().length, 2);
	assertEquals(sample.getSubject(0).getName().toString(), "subject.a");
	assertEquals(sample.getSubject(1).getName().toString(), "subject.b");
	assertNull(sample.getSubject(2));
    }

    public void testSubjectMatter ()
    {
	assertEquals(sample.getSubjectMatterCount(), 2);
	assertEquals(sample.getSubjectMatter().length, 2);
	assertEquals(sample.getSubjectMatter(0).getName().toString(),
		     "matter.a");
	assertEquals(sample.getSubjectMatter(1).getName().toString(),
		     "matter.b");
	assertNull(sample.getSubjectMatter(2));
    }

    public void testSubjectDetail ()
    {
	assertEquals(sample.getSubjectDetailCount(), 2);
	assertEquals(sample.getSubjectDetail().length, 2);
	assertEquals(sample.getSubjectDetail(0).getName().toString(),
		     "detail.a");
	assertEquals(sample.getSubjectDetail(1).getName().toString(),
		     "detail.b");
	assertNull(sample.getSubjectDetail(2));
    }

    public void testSubjectQualifier ()
    {
	assertEquals(sample.getSubjectQualifierCount(), 2);
	assertEquals(sample.getSubjectQualifier().length, 2);
	assertEquals(sample.getSubjectQualifier(0).getName().toString(),
		     "qualifier.a");
	assertEquals(sample.getSubjectQualifier(1).getName().toString(),
		     "qualifier.b");
	assertNull(sample.getSubjectQualifier(2));
    }

    public void testIdentifiers ()
    {
	assertEquals(sample.getDuid().toString(), "subjectcode01");
	assertEquals(sample.getEuid().toString(), "id1");
    }

    public void testAssignment ()
    {
	assertEquals(sample.getAssignedBy().toString(), "assigned-by-5");
	assertEquals(sample.getConfidence().getName().toString(), "confidence-5");
	assertEquals(sample.getAssignmentDateAndTime().toString(),
		     "2000-12-27");
	assertEquals(sample.getHowPresent().getName().toString(), "how-present-5");
	assertEquals(sample.getImportance().getName().toString(), "importance-5");
    }

    public void testItem ()
    {
	assertEquals(sample.getItemCount(), 6);
	assertNotNull(sample.getItem(0));
	assertNotNull(sample.getItem(1));
	assertNotNull(sample.getItem(2));
	assertNotNull(sample.getItem(3));
	assertNotNull(sample.getItem(4));
	assertNotNull(sample.getItem(5));
	assertNull(sample.getItem(6));
    }

    private SubjectCode sample;

}

// end of SubjectCodeTest.java
