// BaseNodePredicate.java - interface for a NewsML node test.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: BaseNodePredicate.java,v 1.5 2001/11/26 16:33:38 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.explorer;

import org.newsml.toolkit.BaseNode;


/**
 * Interface for a NewsML node test.
 *
 * <p>This interface allows applications to plug different kinds
 * of tests into a {@link ExplorerPanel} for highlighting tree
 * nodes, and may have other types of general applicability as
 * well.  To create a new predicate, a class needs to supply
 * an {@link #accept} method that takes a {@link BaseNode}
 * as an argument and returns <var>true</var> if the node
 * passes the test (i.e. it should be highlighted) or
 * <var>false</var> otherwise.  For examples, see the inner classes
 * in {@link ExplorerFrame}.</p>
 *
 * @author Reuters PLC
 * @version 1.1beta
 * @see ExplorerPanel#highlight
 */
public interface BaseNodePredicate
{

    /**
     * Test a NewsML node.
     *
     * @param node The node to test.
     * @return true if the node passes the test, false otherwise.
     */
    public abstract boolean accept (BaseNode node);

}

// end of BaseNodePredicate.java

