// NewsMLTreeModel.java - map a NewsML node structure to a Swing tree.
// Copyright (c) 2000 by Reuters PLC and Wavo Company, Inc.
// $Id: NewsMLTreeModel.java,v 1.11 2001/11/26 16:33:38 dmegginson Exp $

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package org.newsml.toolkit.explorer;

import java.io.Writer;

import javax.swing.event.TreeModelListener;

import javax.swing.tree.TreeModel;
import javax.swing.tree.TreePath;

import org.newsml.toolkit.BaseNode;
import org.newsml.toolkit.NewsML;
import org.newsml.toolkit.NewsMLException;
import org.newsml.toolkit.NewsMLSession;


/**
 * Map a NewsML node structure to a Swing tree.
 *
 * @author Reuters PLC
 * @version 1.1beta
 */
class NewsMLTreeModel implements TreeModel
{

    protected NewsMLTreeModel ()
    {
    }

    protected NewsMLTreeModel (NewsML root)
    {
	this.root = root;
    }

    public Object getRoot ()
    {
	return root;
    }

    public Object getChild (Object parent, int index)
    {
	BaseNode node = ((BaseNode)parent).getChild(index);
	if (node != null)
	    return node;
	else
	    return new DummyBaseNode(parent);
    }

    public int getChildCount (Object parent)
    {
	return ((BaseNode)parent).getChildCount();
    }

    public boolean isLeaf (Object node)
    {
	return (((BaseNode)node).getChildCount() == 0);
    }

    public void valueForPathChanged (TreePath path, Object newValue)
    {
	throw new IllegalStateException("NewsML tree may not be edited");
    }

    public int getIndexOfChild (Object parent, Object child)
    {
	BaseNode node = (BaseNode)parent;
	for (int i = 0; i < node.getChildCount(); i++)
	    if (child.equals(node.getChild(i)))
		return i;
	return -1;
    }

    public void addTreeModelListener (TreeModelListener listener)
    {
	// TODO
    }

    public void removeTreeModelListener (TreeModelListener listener)
    {
	// TODO
    }

    private BaseNode root = null;

    class DummyBaseNode implements BaseNode 
    {
	DummyBaseNode (Object parent)
	{
	    this.parent = parent;
	}

	public String getXMLName ()
	{
	    return "[skipped element]";
	}

	public String getXPath ()
	{
	    return "[no xpath]";
	}

	public NewsMLSession getSession ()
	{
	    return null;
	}

	public BaseNode getParent ()
	{
	    return (BaseNode)parent;
	}

	public int getChildCount ()
	{
	    return 0;
	}

	public int getChildCount (String name)
	{
	    return 0;
	}

	public BaseNode getChild (int index)
	{
	    return null;
	}

	public BaseNode getChild (String name, int index)
	{
	    return null;
	}

	public BaseNode [] getChild () 
	{
	    return new BaseNode[0];
	}

	public BaseNode [] getChild (String name)
	{
	    return new BaseNode[0];
	}

	public BaseNode [] getPath ()
	{
	    return new BaseNode[0];
	}

	public void removeSelf ()
	    throws NewsMLException
	{
	    throw new NewsMLException();
	}

	public String toXML (boolean isDocument)
	{
	    return "";
	}

	public String toXML (String encoding, String internalSubset)
	{
	    return "";
	}

	public void writeXML (Writer output, boolean isDocument)
	{
	    // no op
	}

	public void writeXML (Writer output, String encoding,
			      String internalSubset)
	{
	    // no op
	}

	public String toString ()
	{
	    return getXMLName ();
	}

	private Object parent;
	    
    }

}

// end of NewsMLTreeModel.java
